#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoRenthouseReservationFeedbackSyncModel(object):

    def __init__(self):
        self._audit_comment = None
        self._final_look_time = None
        self._looker_name = None
        self._looker_phone = None
        self._out_biz_no = None
        self._reservation_no = None
        self._reserve_status = None
        self._room_code = None

    @property
    def audit_comment(self):
        return self._audit_comment

    @audit_comment.setter
    def audit_comment(self, value):
        self._audit_comment = value
    @property
    def final_look_time(self):
        return self._final_look_time

    @final_look_time.setter
    def final_look_time(self, value):
        self._final_look_time = value
    @property
    def looker_name(self):
        return self._looker_name

    @looker_name.setter
    def looker_name(self, value):
        self._looker_name = value
    @property
    def looker_phone(self):
        return self._looker_phone

    @looker_phone.setter
    def looker_phone(self, value):
        self._looker_phone = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def reservation_no(self):
        return self._reservation_no

    @reservation_no.setter
    def reservation_no(self, value):
        self._reservation_no = value
    @property
    def reserve_status(self):
        return self._reserve_status

    @reserve_status.setter
    def reserve_status(self, value):
        self._reserve_status = value
    @property
    def room_code(self):
        return self._room_code

    @room_code.setter
    def room_code(self, value):
        self._room_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.audit_comment:
            if hasattr(self.audit_comment, 'to_alipay_dict'):
                params['audit_comment'] = self.audit_comment.to_alipay_dict()
            else:
                params['audit_comment'] = self.audit_comment
        if self.final_look_time:
            if hasattr(self.final_look_time, 'to_alipay_dict'):
                params['final_look_time'] = self.final_look_time.to_alipay_dict()
            else:
                params['final_look_time'] = self.final_look_time
        if self.looker_name:
            if hasattr(self.looker_name, 'to_alipay_dict'):
                params['looker_name'] = self.looker_name.to_alipay_dict()
            else:
                params['looker_name'] = self.looker_name
        if self.looker_phone:
            if hasattr(self.looker_phone, 'to_alipay_dict'):
                params['looker_phone'] = self.looker_phone.to_alipay_dict()
            else:
                params['looker_phone'] = self.looker_phone
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.reservation_no:
            if hasattr(self.reservation_no, 'to_alipay_dict'):
                params['reservation_no'] = self.reservation_no.to_alipay_dict()
            else:
                params['reservation_no'] = self.reservation_no
        if self.reserve_status:
            if hasattr(self.reserve_status, 'to_alipay_dict'):
                params['reserve_status'] = self.reserve_status.to_alipay_dict()
            else:
                params['reserve_status'] = self.reserve_status
        if self.room_code:
            if hasattr(self.room_code, 'to_alipay_dict'):
                params['room_code'] = self.room_code.to_alipay_dict()
            else:
                params['room_code'] = self.room_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoRenthouseReservationFeedbackSyncModel()
        if 'audit_comment' in d:
            o.audit_comment = d['audit_comment']
        if 'final_look_time' in d:
            o.final_look_time = d['final_look_time']
        if 'looker_name' in d:
            o.looker_name = d['looker_name']
        if 'looker_phone' in d:
            o.looker_phone = d['looker_phone']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'reservation_no' in d:
            o.reservation_no = d['reservation_no']
        if 'reserve_status' in d:
            o.reserve_status = d['reserve_status']
        if 'room_code' in d:
            o.room_code = d['room_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DataSyncPayload import DataSyncPayload


class AlipayMsaasItapDataSyncModel(object):

    def __init__(self):
        self._payload = None
        self._request_id = None
        self._user_id = None

    @property
    def payload(self):
        return self._payload

    @payload.setter
    def payload(self, value):
        if isinstance(value, DataSyncPayload):
            self._payload = value
        else:
            self._payload = DataSyncPayload.from_alipay_dict(value)
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.payload:
            if hasattr(self.payload, 'to_alipay_dict'):
                params['payload'] = self.payload.to_alipay_dict()
            else:
                params['payload'] = self.payload
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMsaasItapDataSyncModel()
        if 'payload' in d:
            o.payload = d['payload']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MMemberLevel import MMemberLevel


class MPromoConstraint(object):

    def __init__(self):
        self._crowd_type = None
        self._member_levels = None
        self._need_crowd_flag = None
        self._sub_dimension = None
        self._sub_win_count = None
        self._suit_shop_ids = None
        self._total_win_count = None

    @property
    def crowd_type(self):
        return self._crowd_type

    @crowd_type.setter
    def crowd_type(self, value):
        self._crowd_type = value
    @property
    def member_levels(self):
        return self._member_levels

    @member_levels.setter
    def member_levels(self, value):
        if isinstance(value, list):
            self._member_levels = list()
            for i in value:
                if isinstance(i, MMemberLevel):
                    self._member_levels.append(i)
                else:
                    self._member_levels.append(MMemberLevel.from_alipay_dict(i))
    @property
    def need_crowd_flag(self):
        return self._need_crowd_flag

    @need_crowd_flag.setter
    def need_crowd_flag(self, value):
        self._need_crowd_flag = value
    @property
    def sub_dimension(self):
        return self._sub_dimension

    @sub_dimension.setter
    def sub_dimension(self, value):
        self._sub_dimension = value
    @property
    def sub_win_count(self):
        return self._sub_win_count

    @sub_win_count.setter
    def sub_win_count(self, value):
        self._sub_win_count = value
    @property
    def suit_shop_ids(self):
        return self._suit_shop_ids

    @suit_shop_ids.setter
    def suit_shop_ids(self, value):
        if isinstance(value, list):
            self._suit_shop_ids = list()
            for i in value:
                self._suit_shop_ids.append(i)
    @property
    def total_win_count(self):
        return self._total_win_count

    @total_win_count.setter
    def total_win_count(self, value):
        self._total_win_count = value


    def to_alipay_dict(self):
        params = dict()
        if self.crowd_type:
            if hasattr(self.crowd_type, 'to_alipay_dict'):
                params['crowd_type'] = self.crowd_type.to_alipay_dict()
            else:
                params['crowd_type'] = self.crowd_type
        if self.member_levels:
            if isinstance(self.member_levels, list):
                for i in range(0, len(self.member_levels)):
                    element = self.member_levels[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.member_levels[i] = element.to_alipay_dict()
            if hasattr(self.member_levels, 'to_alipay_dict'):
                params['member_levels'] = self.member_levels.to_alipay_dict()
            else:
                params['member_levels'] = self.member_levels
        if self.need_crowd_flag:
            if hasattr(self.need_crowd_flag, 'to_alipay_dict'):
                params['need_crowd_flag'] = self.need_crowd_flag.to_alipay_dict()
            else:
                params['need_crowd_flag'] = self.need_crowd_flag
        if self.sub_dimension:
            if hasattr(self.sub_dimension, 'to_alipay_dict'):
                params['sub_dimension'] = self.sub_dimension.to_alipay_dict()
            else:
                params['sub_dimension'] = self.sub_dimension
        if self.sub_win_count:
            if hasattr(self.sub_win_count, 'to_alipay_dict'):
                params['sub_win_count'] = self.sub_win_count.to_alipay_dict()
            else:
                params['sub_win_count'] = self.sub_win_count
        if self.suit_shop_ids:
            if isinstance(self.suit_shop_ids, list):
                for i in range(0, len(self.suit_shop_ids)):
                    element = self.suit_shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.suit_shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.suit_shop_ids, 'to_alipay_dict'):
                params['suit_shop_ids'] = self.suit_shop_ids.to_alipay_dict()
            else:
                params['suit_shop_ids'] = self.suit_shop_ids
        if self.total_win_count:
            if hasattr(self.total_win_count, 'to_alipay_dict'):
                params['total_win_count'] = self.total_win_count.to_alipay_dict()
            else:
                params['total_win_count'] = self.total_win_count
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MPromoConstraint()
        if 'crowd_type' in d:
            o.crowd_type = d['crowd_type']
        if 'member_levels' in d:
            o.member_levels = d['member_levels']
        if 'need_crowd_flag' in d:
            o.need_crowd_flag = d['need_crowd_flag']
        if 'sub_dimension' in d:
            o.sub_dimension = d['sub_dimension']
        if 'sub_win_count' in d:
            o.sub_win_count = d['sub_win_count']
        if 'suit_shop_ids' in d:
            o.suit_shop_ids = d['suit_shop_ids']
        if 'total_win_count' in d:
            o.total_win_count = d['total_win_count']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.RefundActivityInfo import RefundActivityInfo


class AlipayMarketingActivityOrderRefundModel(object):

    def __init__(self):
        self._buyer_id = None
        self._order_no = None
        self._out_biz_no = None
        self._refund_activity_info_list = None
        self._refund_type = None

    @property
    def buyer_id(self):
        return self._buyer_id

    @buyer_id.setter
    def buyer_id(self, value):
        self._buyer_id = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def refund_activity_info_list(self):
        return self._refund_activity_info_list

    @refund_activity_info_list.setter
    def refund_activity_info_list(self, value):
        if isinstance(value, list):
            self._refund_activity_info_list = list()
            for i in value:
                if isinstance(i, RefundActivityInfo):
                    self._refund_activity_info_list.append(i)
                else:
                    self._refund_activity_info_list.append(RefundActivityInfo.from_alipay_dict(i))
    @property
    def refund_type(self):
        return self._refund_type

    @refund_type.setter
    def refund_type(self, value):
        self._refund_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.buyer_id:
            if hasattr(self.buyer_id, 'to_alipay_dict'):
                params['buyer_id'] = self.buyer_id.to_alipay_dict()
            else:
                params['buyer_id'] = self.buyer_id
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.refund_activity_info_list:
            if isinstance(self.refund_activity_info_list, list):
                for i in range(0, len(self.refund_activity_info_list)):
                    element = self.refund_activity_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.refund_activity_info_list[i] = element.to_alipay_dict()
            if hasattr(self.refund_activity_info_list, 'to_alipay_dict'):
                params['refund_activity_info_list'] = self.refund_activity_info_list.to_alipay_dict()
            else:
                params['refund_activity_info_list'] = self.refund_activity_info_list
        if self.refund_type:
            if hasattr(self.refund_type, 'to_alipay_dict'):
                params['refund_type'] = self.refund_type.to_alipay_dict()
            else:
                params['refund_type'] = self.refund_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingActivityOrderRefundModel()
        if 'buyer_id' in d:
            o.buyer_id = d['buyer_id']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'refund_activity_info_list' in d:
            o.refund_activity_info_list = d['refund_activity_info_list']
        if 'refund_type' in d:
            o.refund_type = d['refund_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFincoreComplianceApccenterAlgorithmbaseinfoModifyModel(object):

    def __init__(self):
        self._platform_algorithm_code = None
        self._platform_algorithm_create_time = None
        self._platform_algorithm_desc = None
        self._platform_algorithm_last_iteration_code = None
        self._platform_algorithm_last_iteration_op_user_emp_no = None
        self._platform_algorithm_modify_time = None
        self._platform_algorithm_name = None
        self._platform_algorithm_owner_emp_no = None
        self._platform_algorithm_source = None
        self._platform_algorithm_status = None

    @property
    def platform_algorithm_code(self):
        return self._platform_algorithm_code

    @platform_algorithm_code.setter
    def platform_algorithm_code(self, value):
        self._platform_algorithm_code = value
    @property
    def platform_algorithm_create_time(self):
        return self._platform_algorithm_create_time

    @platform_algorithm_create_time.setter
    def platform_algorithm_create_time(self, value):
        self._platform_algorithm_create_time = value
    @property
    def platform_algorithm_desc(self):
        return self._platform_algorithm_desc

    @platform_algorithm_desc.setter
    def platform_algorithm_desc(self, value):
        self._platform_algorithm_desc = value
    @property
    def platform_algorithm_last_iteration_code(self):
        return self._platform_algorithm_last_iteration_code

    @platform_algorithm_last_iteration_code.setter
    def platform_algorithm_last_iteration_code(self, value):
        self._platform_algorithm_last_iteration_code = value
    @property
    def platform_algorithm_last_iteration_op_user_emp_no(self):
        return self._platform_algorithm_last_iteration_op_user_emp_no

    @platform_algorithm_last_iteration_op_user_emp_no.setter
    def platform_algorithm_last_iteration_op_user_emp_no(self, value):
        self._platform_algorithm_last_iteration_op_user_emp_no = value
    @property
    def platform_algorithm_modify_time(self):
        return self._platform_algorithm_modify_time

    @platform_algorithm_modify_time.setter
    def platform_algorithm_modify_time(self, value):
        self._platform_algorithm_modify_time = value
    @property
    def platform_algorithm_name(self):
        return self._platform_algorithm_name

    @platform_algorithm_name.setter
    def platform_algorithm_name(self, value):
        self._platform_algorithm_name = value
    @property
    def platform_algorithm_owner_emp_no(self):
        return self._platform_algorithm_owner_emp_no

    @platform_algorithm_owner_emp_no.setter
    def platform_algorithm_owner_emp_no(self, value):
        self._platform_algorithm_owner_emp_no = value
    @property
    def platform_algorithm_source(self):
        return self._platform_algorithm_source

    @platform_algorithm_source.setter
    def platform_algorithm_source(self, value):
        self._platform_algorithm_source = value
    @property
    def platform_algorithm_status(self):
        return self._platform_algorithm_status

    @platform_algorithm_status.setter
    def platform_algorithm_status(self, value):
        self._platform_algorithm_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.platform_algorithm_code:
            if hasattr(self.platform_algorithm_code, 'to_alipay_dict'):
                params['platform_algorithm_code'] = self.platform_algorithm_code.to_alipay_dict()
            else:
                params['platform_algorithm_code'] = self.platform_algorithm_code
        if self.platform_algorithm_create_time:
            if hasattr(self.platform_algorithm_create_time, 'to_alipay_dict'):
                params['platform_algorithm_create_time'] = self.platform_algorithm_create_time.to_alipay_dict()
            else:
                params['platform_algorithm_create_time'] = self.platform_algorithm_create_time
        if self.platform_algorithm_desc:
            if hasattr(self.platform_algorithm_desc, 'to_alipay_dict'):
                params['platform_algorithm_desc'] = self.platform_algorithm_desc.to_alipay_dict()
            else:
                params['platform_algorithm_desc'] = self.platform_algorithm_desc
        if self.platform_algorithm_last_iteration_code:
            if hasattr(self.platform_algorithm_last_iteration_code, 'to_alipay_dict'):
                params['platform_algorithm_last_iteration_code'] = self.platform_algorithm_last_iteration_code.to_alipay_dict()
            else:
                params['platform_algorithm_last_iteration_code'] = self.platform_algorithm_last_iteration_code
        if self.platform_algorithm_last_iteration_op_user_emp_no:
            if hasattr(self.platform_algorithm_last_iteration_op_user_emp_no, 'to_alipay_dict'):
                params['platform_algorithm_last_iteration_op_user_emp_no'] = self.platform_algorithm_last_iteration_op_user_emp_no.to_alipay_dict()
            else:
                params['platform_algorithm_last_iteration_op_user_emp_no'] = self.platform_algorithm_last_iteration_op_user_emp_no
        if self.platform_algorithm_modify_time:
            if hasattr(self.platform_algorithm_modify_time, 'to_alipay_dict'):
                params['platform_algorithm_modify_time'] = self.platform_algorithm_modify_time.to_alipay_dict()
            else:
                params['platform_algorithm_modify_time'] = self.platform_algorithm_modify_time
        if self.platform_algorithm_name:
            if hasattr(self.platform_algorithm_name, 'to_alipay_dict'):
                params['platform_algorithm_name'] = self.platform_algorithm_name.to_alipay_dict()
            else:
                params['platform_algorithm_name'] = self.platform_algorithm_name
        if self.platform_algorithm_owner_emp_no:
            if hasattr(self.platform_algorithm_owner_emp_no, 'to_alipay_dict'):
                params['platform_algorithm_owner_emp_no'] = self.platform_algorithm_owner_emp_no.to_alipay_dict()
            else:
                params['platform_algorithm_owner_emp_no'] = self.platform_algorithm_owner_emp_no
        if self.platform_algorithm_source:
            if hasattr(self.platform_algorithm_source, 'to_alipay_dict'):
                params['platform_algorithm_source'] = self.platform_algorithm_source.to_alipay_dict()
            else:
                params['platform_algorithm_source'] = self.platform_algorithm_source
        if self.platform_algorithm_status:
            if hasattr(self.platform_algorithm_status, 'to_alipay_dict'):
                params['platform_algorithm_status'] = self.platform_algorithm_status.to_alipay_dict()
            else:
                params['platform_algorithm_status'] = self.platform_algorithm_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFincoreComplianceApccenterAlgorithmbaseinfoModifyModel()
        if 'platform_algorithm_code' in d:
            o.platform_algorithm_code = d['platform_algorithm_code']
        if 'platform_algorithm_create_time' in d:
            o.platform_algorithm_create_time = d['platform_algorithm_create_time']
        if 'platform_algorithm_desc' in d:
            o.platform_algorithm_desc = d['platform_algorithm_desc']
        if 'platform_algorithm_last_iteration_code' in d:
            o.platform_algorithm_last_iteration_code = d['platform_algorithm_last_iteration_code']
        if 'platform_algorithm_last_iteration_op_user_emp_no' in d:
            o.platform_algorithm_last_iteration_op_user_emp_no = d['platform_algorithm_last_iteration_op_user_emp_no']
        if 'platform_algorithm_modify_time' in d:
            o.platform_algorithm_modify_time = d['platform_algorithm_modify_time']
        if 'platform_algorithm_name' in d:
            o.platform_algorithm_name = d['platform_algorithm_name']
        if 'platform_algorithm_owner_emp_no' in d:
            o.platform_algorithm_owner_emp_no = d['platform_algorithm_owner_emp_no']
        if 'platform_algorithm_source' in d:
            o.platform_algorithm_source = d['platform_algorithm_source']
        if 'platform_algorithm_status' in d:
            o.platform_algorithm_status = d['platform_algorithm_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MedicalSvTpCardActionInfo(object):

    def __init__(self):
        self._action_code = None
        self._action_name = None
        self._action_url = None

    @property
    def action_code(self):
        return self._action_code

    @action_code.setter
    def action_code(self, value):
        self._action_code = value
    @property
    def action_name(self):
        return self._action_name

    @action_name.setter
    def action_name(self, value):
        self._action_name = value
    @property
    def action_url(self):
        return self._action_url

    @action_url.setter
    def action_url(self, value):
        self._action_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_code:
            if hasattr(self.action_code, 'to_alipay_dict'):
                params['action_code'] = self.action_code.to_alipay_dict()
            else:
                params['action_code'] = self.action_code
        if self.action_name:
            if hasattr(self.action_name, 'to_alipay_dict'):
                params['action_name'] = self.action_name.to_alipay_dict()
            else:
                params['action_name'] = self.action_name
        if self.action_url:
            if hasattr(self.action_url, 'to_alipay_dict'):
                params['action_url'] = self.action_url.to_alipay_dict()
            else:
                params['action_url'] = self.action_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MedicalSvTpCardActionInfo()
        if 'action_code' in d:
            o.action_code = d['action_code']
        if 'action_name' in d:
            o.action_name = d['action_name']
        if 'action_url' in d:
            o.action_url = d['action_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenSpLeadsExpandCreateModel(object):

    def __init__(self):
        self._address = None
        self._city_code = None
        self._city_name = None
        self._district_code = None
        self._district_name = None
        self._email = None
        self._latitude = None
        self._longitude = None
        self._mcc = None
        self._merchant_pid = None
        self._name = None
        self._out_biz_no = None
        self._phone = None
        self._province_code = None
        self._province_name = None
        self._scene = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def district_name(self):
        return self._district_name

    @district_name.setter
    def district_name(self, value):
        self._district_name = value
    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def mcc(self):
        return self._mcc

    @mcc.setter
    def mcc(self, value):
        self._mcc = value
    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        self._phone = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def province_name(self):
        return self._province_name

    @province_name.setter
    def province_name(self, value):
        self._province_name = value
    @property
    def scene(self):
        return self._scene

    @scene.setter
    def scene(self, value):
        self._scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.city_name:
            if hasattr(self.city_name, 'to_alipay_dict'):
                params['city_name'] = self.city_name.to_alipay_dict()
            else:
                params['city_name'] = self.city_name
        if self.district_code:
            if hasattr(self.district_code, 'to_alipay_dict'):
                params['district_code'] = self.district_code.to_alipay_dict()
            else:
                params['district_code'] = self.district_code
        if self.district_name:
            if hasattr(self.district_name, 'to_alipay_dict'):
                params['district_name'] = self.district_name.to_alipay_dict()
            else:
                params['district_name'] = self.district_name
        if self.email:
            if hasattr(self.email, 'to_alipay_dict'):
                params['email'] = self.email.to_alipay_dict()
            else:
                params['email'] = self.email
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.mcc:
            if hasattr(self.mcc, 'to_alipay_dict'):
                params['mcc'] = self.mcc.to_alipay_dict()
            else:
                params['mcc'] = self.mcc
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.phone:
            if hasattr(self.phone, 'to_alipay_dict'):
                params['phone'] = self.phone.to_alipay_dict()
            else:
                params['phone'] = self.phone
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.province_name:
            if hasattr(self.province_name, 'to_alipay_dict'):
                params['province_name'] = self.province_name.to_alipay_dict()
            else:
                params['province_name'] = self.province_name
        if self.scene:
            if hasattr(self.scene, 'to_alipay_dict'):
                params['scene'] = self.scene.to_alipay_dict()
            else:
                params['scene'] = self.scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenSpLeadsExpandCreateModel()
        if 'address' in d:
            o.address = d['address']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'city_name' in d:
            o.city_name = d['city_name']
        if 'district_code' in d:
            o.district_code = d['district_code']
        if 'district_name' in d:
            o.district_name = d['district_name']
        if 'email' in d:
            o.email = d['email']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'mcc' in d:
            o.mcc = d['mcc']
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        if 'name' in d:
            o.name = d['name']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'phone' in d:
            o.phone = d['phone']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'province_name' in d:
            o.province_name = d['province_name']
        if 'scene' in d:
            o.scene = d['scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PaytoolCancelRequestDetail(object):

    def __init__(self):
        self._paytool_bill_no = None
        self._paytool_request_no = None

    @property
    def paytool_bill_no(self):
        return self._paytool_bill_no

    @paytool_bill_no.setter
    def paytool_bill_no(self, value):
        self._paytool_bill_no = value
    @property
    def paytool_request_no(self):
        return self._paytool_request_no

    @paytool_request_no.setter
    def paytool_request_no(self, value):
        self._paytool_request_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.paytool_bill_no:
            if hasattr(self.paytool_bill_no, 'to_alipay_dict'):
                params['paytool_bill_no'] = self.paytool_bill_no.to_alipay_dict()
            else:
                params['paytool_bill_no'] = self.paytool_bill_no
        if self.paytool_request_no:
            if hasattr(self.paytool_request_no, 'to_alipay_dict'):
                params['paytool_request_no'] = self.paytool_request_no.to_alipay_dict()
            else:
                params['paytool_request_no'] = self.paytool_request_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaytoolCancelRequestDetail()
        if 'paytool_bill_no' in d:
            o.paytool_bill_no = d['paytool_bill_no']
        if 'paytool_request_no' in d:
            o.paytool_request_no = d['paytool_request_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ShopServiceItem(object):

    def __init__(self):
        self._description = None
        self._name = None
        self._pictures = None

    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def pictures(self):
        return self._pictures

    @pictures.setter
    def pictures(self, value):
        if isinstance(value, list):
            self._pictures = list()
            for i in value:
                self._pictures.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.pictures:
            if isinstance(self.pictures, list):
                for i in range(0, len(self.pictures)):
                    element = self.pictures[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pictures[i] = element.to_alipay_dict()
            if hasattr(self.pictures, 'to_alipay_dict'):
                params['pictures'] = self.pictures.to_alipay_dict()
            else:
                params['pictures'] = self.pictures
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ShopServiceItem()
        if 'description' in d:
            o.description = d['description']
        if 'name' in d:
            o.name = d['name']
        if 'pictures' in d:
            o.pictures = d['pictures']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayZmScoreZrankResult(object):

    def __init__(self):
        self._zrank = None

    @property
    def zrank(self):
        return self._zrank

    @zrank.setter
    def zrank(self, value):
        self._zrank = value


    def to_alipay_dict(self):
        params = dict()
        if self.zrank:
            if hasattr(self.zrank, 'to_alipay_dict'):
                params['zrank'] = self.zrank.to_alipay_dict()
            else:
                params['zrank'] = self.zrank
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayZmScoreZrankResult()
        if 'zrank' in d:
            o.zrank = d['zrank']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PriceInformation import PriceInformation
from alipay.aop.api.domain.BizUnitInfo import BizUnitInfo
from alipay.aop.api.domain.UserIdentity import UserIdentity
from alipay.aop.api.domain.OrderExtInfo import OrderExtInfo
from alipay.aop.api.domain.UserIdentity import UserIdentity
from alipay.aop.api.domain.UserIdentity import UserIdentity
from alipay.aop.api.domain.PriceInformation import PriceInformation
from alipay.aop.api.domain.UserIdentity import UserIdentity


class AlipayMerchantOrderMessageSyncModel(object):

    def __init__(self):
        self._actual_amount = None
        self._alipay_trade_no = None
        self._biz_order_no = None
        self._biz_type = None
        self._biz_unit_info = None
        self._buyer = None
        self._callback_url = None
        self._create_time = None
        self._deliver_status = None
        self._deliver_status_desc = None
        self._ext_info = None
        self._external_buyer = None
        self._external_order_no = None
        self._external_seller = None
        self._item_title = None
        self._modify_time = None
        self._order_amount = None
        self._order_status = None
        self._order_status_desc = None
        self._partner_id = None
        self._pay_status = None
        self._pay_status_desc = None
        self._pay_time = None
        self._refund_status = None
        self._refund_status_desc = None
        self._seller = None
        self._source = None
        self._sub_biz_type = None
        self._system_name = None

    @property
    def actual_amount(self):
        return self._actual_amount

    @actual_amount.setter
    def actual_amount(self, value):
        if isinstance(value, list):
            self._actual_amount = list()
            for i in value:
                if isinstance(i, PriceInformation):
                    self._actual_amount.append(i)
                else:
                    self._actual_amount.append(PriceInformation.from_alipay_dict(i))
    @property
    def alipay_trade_no(self):
        return self._alipay_trade_no

    @alipay_trade_no.setter
    def alipay_trade_no(self, value):
        self._alipay_trade_no = value
    @property
    def biz_order_no(self):
        return self._biz_order_no

    @biz_order_no.setter
    def biz_order_no(self, value):
        self._biz_order_no = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def biz_unit_info(self):
        return self._biz_unit_info

    @biz_unit_info.setter
    def biz_unit_info(self, value):
        if isinstance(value, BizUnitInfo):
            self._biz_unit_info = value
        else:
            self._biz_unit_info = BizUnitInfo.from_alipay_dict(value)
    @property
    def buyer(self):
        return self._buyer

    @buyer.setter
    def buyer(self, value):
        if isinstance(value, UserIdentity):
            self._buyer = value
        else:
            self._buyer = UserIdentity.from_alipay_dict(value)
    @property
    def callback_url(self):
        return self._callback_url

    @callback_url.setter
    def callback_url(self, value):
        self._callback_url = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def deliver_status(self):
        return self._deliver_status

    @deliver_status.setter
    def deliver_status(self, value):
        self._deliver_status = value
    @property
    def deliver_status_desc(self):
        return self._deliver_status_desc

    @deliver_status_desc.setter
    def deliver_status_desc(self, value):
        self._deliver_status_desc = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, list):
            self._ext_info = list()
            for i in value:
                if isinstance(i, OrderExtInfo):
                    self._ext_info.append(i)
                else:
                    self._ext_info.append(OrderExtInfo.from_alipay_dict(i))
    @property
    def external_buyer(self):
        return self._external_buyer

    @external_buyer.setter
    def external_buyer(self, value):
        if isinstance(value, UserIdentity):
            self._external_buyer = value
        else:
            self._external_buyer = UserIdentity.from_alipay_dict(value)
    @property
    def external_order_no(self):
        return self._external_order_no

    @external_order_no.setter
    def external_order_no(self, value):
        self._external_order_no = value
    @property
    def external_seller(self):
        return self._external_seller

    @external_seller.setter
    def external_seller(self, value):
        if isinstance(value, UserIdentity):
            self._external_seller = value
        else:
            self._external_seller = UserIdentity.from_alipay_dict(value)
    @property
    def item_title(self):
        return self._item_title

    @item_title.setter
    def item_title(self, value):
        self._item_title = value
    @property
    def modify_time(self):
        return self._modify_time

    @modify_time.setter
    def modify_time(self, value):
        self._modify_time = value
    @property
    def order_amount(self):
        return self._order_amount

    @order_amount.setter
    def order_amount(self, value):
        if isinstance(value, list):
            self._order_amount = list()
            for i in value:
                if isinstance(i, PriceInformation):
                    self._order_amount.append(i)
                else:
                    self._order_amount.append(PriceInformation.from_alipay_dict(i))
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def order_status_desc(self):
        return self._order_status_desc

    @order_status_desc.setter
    def order_status_desc(self, value):
        self._order_status_desc = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def pay_status(self):
        return self._pay_status

    @pay_status.setter
    def pay_status(self, value):
        self._pay_status = value
    @property
    def pay_status_desc(self):
        return self._pay_status_desc

    @pay_status_desc.setter
    def pay_status_desc(self, value):
        self._pay_status_desc = value
    @property
    def pay_time(self):
        return self._pay_time

    @pay_time.setter
    def pay_time(self, value):
        self._pay_time = value
    @property
    def refund_status(self):
        return self._refund_status

    @refund_status.setter
    def refund_status(self, value):
        self._refund_status = value
    @property
    def refund_status_desc(self):
        return self._refund_status_desc

    @refund_status_desc.setter
    def refund_status_desc(self, value):
        self._refund_status_desc = value
    @property
    def seller(self):
        return self._seller

    @seller.setter
    def seller(self, value):
        if isinstance(value, UserIdentity):
            self._seller = value
        else:
            self._seller = UserIdentity.from_alipay_dict(value)
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value
    @property
    def system_name(self):
        return self._system_name

    @system_name.setter
    def system_name(self, value):
        self._system_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.actual_amount:
            if isinstance(self.actual_amount, list):
                for i in range(0, len(self.actual_amount)):
                    element = self.actual_amount[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.actual_amount[i] = element.to_alipay_dict()
            if hasattr(self.actual_amount, 'to_alipay_dict'):
                params['actual_amount'] = self.actual_amount.to_alipay_dict()
            else:
                params['actual_amount'] = self.actual_amount
        if self.alipay_trade_no:
            if hasattr(self.alipay_trade_no, 'to_alipay_dict'):
                params['alipay_trade_no'] = self.alipay_trade_no.to_alipay_dict()
            else:
                params['alipay_trade_no'] = self.alipay_trade_no
        if self.biz_order_no:
            if hasattr(self.biz_order_no, 'to_alipay_dict'):
                params['biz_order_no'] = self.biz_order_no.to_alipay_dict()
            else:
                params['biz_order_no'] = self.biz_order_no
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.biz_unit_info:
            if hasattr(self.biz_unit_info, 'to_alipay_dict'):
                params['biz_unit_info'] = self.biz_unit_info.to_alipay_dict()
            else:
                params['biz_unit_info'] = self.biz_unit_info
        if self.buyer:
            if hasattr(self.buyer, 'to_alipay_dict'):
                params['buyer'] = self.buyer.to_alipay_dict()
            else:
                params['buyer'] = self.buyer
        if self.callback_url:
            if hasattr(self.callback_url, 'to_alipay_dict'):
                params['callback_url'] = self.callback_url.to_alipay_dict()
            else:
                params['callback_url'] = self.callback_url
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.deliver_status:
            if hasattr(self.deliver_status, 'to_alipay_dict'):
                params['deliver_status'] = self.deliver_status.to_alipay_dict()
            else:
                params['deliver_status'] = self.deliver_status
        if self.deliver_status_desc:
            if hasattr(self.deliver_status_desc, 'to_alipay_dict'):
                params['deliver_status_desc'] = self.deliver_status_desc.to_alipay_dict()
            else:
                params['deliver_status_desc'] = self.deliver_status_desc
        if self.ext_info:
            if isinstance(self.ext_info, list):
                for i in range(0, len(self.ext_info)):
                    element = self.ext_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_info[i] = element.to_alipay_dict()
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.external_buyer:
            if hasattr(self.external_buyer, 'to_alipay_dict'):
                params['external_buyer'] = self.external_buyer.to_alipay_dict()
            else:
                params['external_buyer'] = self.external_buyer
        if self.external_order_no:
            if hasattr(self.external_order_no, 'to_alipay_dict'):
                params['external_order_no'] = self.external_order_no.to_alipay_dict()
            else:
                params['external_order_no'] = self.external_order_no
        if self.external_seller:
            if hasattr(self.external_seller, 'to_alipay_dict'):
                params['external_seller'] = self.external_seller.to_alipay_dict()
            else:
                params['external_seller'] = self.external_seller
        if self.item_title:
            if hasattr(self.item_title, 'to_alipay_dict'):
                params['item_title'] = self.item_title.to_alipay_dict()
            else:
                params['item_title'] = self.item_title
        if self.modify_time:
            if hasattr(self.modify_time, 'to_alipay_dict'):
                params['modify_time'] = self.modify_time.to_alipay_dict()
            else:
                params['modify_time'] = self.modify_time
        if self.order_amount:
            if isinstance(self.order_amount, list):
                for i in range(0, len(self.order_amount)):
                    element = self.order_amount[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.order_amount[i] = element.to_alipay_dict()
            if hasattr(self.order_amount, 'to_alipay_dict'):
                params['order_amount'] = self.order_amount.to_alipay_dict()
            else:
                params['order_amount'] = self.order_amount
        if self.order_status:
            if hasattr(self.order_status, 'to_alipay_dict'):
                params['order_status'] = self.order_status.to_alipay_dict()
            else:
                params['order_status'] = self.order_status
        if self.order_status_desc:
            if hasattr(self.order_status_desc, 'to_alipay_dict'):
                params['order_status_desc'] = self.order_status_desc.to_alipay_dict()
            else:
                params['order_status_desc'] = self.order_status_desc
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.pay_status:
            if hasattr(self.pay_status, 'to_alipay_dict'):
                params['pay_status'] = self.pay_status.to_alipay_dict()
            else:
                params['pay_status'] = self.pay_status
        if self.pay_status_desc:
            if hasattr(self.pay_status_desc, 'to_alipay_dict'):
                params['pay_status_desc'] = self.pay_status_desc.to_alipay_dict()
            else:
                params['pay_status_desc'] = self.pay_status_desc
        if self.pay_time:
            if hasattr(self.pay_time, 'to_alipay_dict'):
                params['pay_time'] = self.pay_time.to_alipay_dict()
            else:
                params['pay_time'] = self.pay_time
        if self.refund_status:
            if hasattr(self.refund_status, 'to_alipay_dict'):
                params['refund_status'] = self.refund_status.to_alipay_dict()
            else:
                params['refund_status'] = self.refund_status
        if self.refund_status_desc:
            if hasattr(self.refund_status_desc, 'to_alipay_dict'):
                params['refund_status_desc'] = self.refund_status_desc.to_alipay_dict()
            else:
                params['refund_status_desc'] = self.refund_status_desc
        if self.seller:
            if hasattr(self.seller, 'to_alipay_dict'):
                params['seller'] = self.seller.to_alipay_dict()
            else:
                params['seller'] = self.seller
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        if self.system_name:
            if hasattr(self.system_name, 'to_alipay_dict'):
                params['system_name'] = self.system_name.to_alipay_dict()
            else:
                params['system_name'] = self.system_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantOrderMessageSyncModel()
        if 'actual_amount' in d:
            o.actual_amount = d['actual_amount']
        if 'alipay_trade_no' in d:
            o.alipay_trade_no = d['alipay_trade_no']
        if 'biz_order_no' in d:
            o.biz_order_no = d['biz_order_no']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'biz_unit_info' in d:
            o.biz_unit_info = d['biz_unit_info']
        if 'buyer' in d:
            o.buyer = d['buyer']
        if 'callback_url' in d:
            o.callback_url = d['callback_url']
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'deliver_status' in d:
            o.deliver_status = d['deliver_status']
        if 'deliver_status_desc' in d:
            o.deliver_status_desc = d['deliver_status_desc']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'external_buyer' in d:
            o.external_buyer = d['external_buyer']
        if 'external_order_no' in d:
            o.external_order_no = d['external_order_no']
        if 'external_seller' in d:
            o.external_seller = d['external_seller']
        if 'item_title' in d:
            o.item_title = d['item_title']
        if 'modify_time' in d:
            o.modify_time = d['modify_time']
        if 'order_amount' in d:
            o.order_amount = d['order_amount']
        if 'order_status' in d:
            o.order_status = d['order_status']
        if 'order_status_desc' in d:
            o.order_status_desc = d['order_status_desc']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'pay_status' in d:
            o.pay_status = d['pay_status']
        if 'pay_status_desc' in d:
            o.pay_status_desc = d['pay_status_desc']
        if 'pay_time' in d:
            o.pay_time = d['pay_time']
        if 'refund_status' in d:
            o.refund_status = d['refund_status']
        if 'refund_status_desc' in d:
            o.refund_status_desc = d['refund_status_desc']
        if 'seller' in d:
            o.seller = d['seller']
        if 'source' in d:
            o.source = d['source']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        if 'system_name' in d:
            o.system_name = d['system_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Member import Member
from alipay.aop.api.domain.Member import Member


class MybankCreditSupplychainTradeNettingRefundModel(object):

    def __init__(self):
        self._buyer = None
        self._channel = None
        self._out_order_no = None
        self._out_refund_no = None
        self._refund_amount = None
        self._request_id = None
        self._sale_pd_code = None
        self._seller = None
        self._trade_type = None

    @property
    def buyer(self):
        return self._buyer

    @buyer.setter
    def buyer(self, value):
        if isinstance(value, Member):
            self._buyer = value
        else:
            self._buyer = Member.from_alipay_dict(value)
    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def out_refund_no(self):
        return self._out_refund_no

    @out_refund_no.setter
    def out_refund_no(self, value):
        self._out_refund_no = value
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def sale_pd_code(self):
        return self._sale_pd_code

    @sale_pd_code.setter
    def sale_pd_code(self, value):
        self._sale_pd_code = value
    @property
    def seller(self):
        return self._seller

    @seller.setter
    def seller(self, value):
        if isinstance(value, Member):
            self._seller = value
        else:
            self._seller = Member.from_alipay_dict(value)
    @property
    def trade_type(self):
        return self._trade_type

    @trade_type.setter
    def trade_type(self, value):
        self._trade_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.buyer:
            if hasattr(self.buyer, 'to_alipay_dict'):
                params['buyer'] = self.buyer.to_alipay_dict()
            else:
                params['buyer'] = self.buyer
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.out_refund_no:
            if hasattr(self.out_refund_no, 'to_alipay_dict'):
                params['out_refund_no'] = self.out_refund_no.to_alipay_dict()
            else:
                params['out_refund_no'] = self.out_refund_no
        if self.refund_amount:
            if hasattr(self.refund_amount, 'to_alipay_dict'):
                params['refund_amount'] = self.refund_amount.to_alipay_dict()
            else:
                params['refund_amount'] = self.refund_amount
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.sale_pd_code:
            if hasattr(self.sale_pd_code, 'to_alipay_dict'):
                params['sale_pd_code'] = self.sale_pd_code.to_alipay_dict()
            else:
                params['sale_pd_code'] = self.sale_pd_code
        if self.seller:
            if hasattr(self.seller, 'to_alipay_dict'):
                params['seller'] = self.seller.to_alipay_dict()
            else:
                params['seller'] = self.seller
        if self.trade_type:
            if hasattr(self.trade_type, 'to_alipay_dict'):
                params['trade_type'] = self.trade_type.to_alipay_dict()
            else:
                params['trade_type'] = self.trade_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditSupplychainTradeNettingRefundModel()
        if 'buyer' in d:
            o.buyer = d['buyer']
        if 'channel' in d:
            o.channel = d['channel']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'out_refund_no' in d:
            o.out_refund_no = d['out_refund_no']
        if 'refund_amount' in d:
            o.refund_amount = d['refund_amount']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'sale_pd_code' in d:
            o.sale_pd_code = d['sale_pd_code']
        if 'seller' in d:
            o.seller = d['seller']
        if 'trade_type' in d:
            o.trade_type = d['trade_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CorpEntity(object):

    def __init__(self):
        self._agent_cert_name = None
        self._agent_cert_no = None
        self._alipay_account = None
        self._corp_code = None
        self._corp_name = None
        self._corp_type = None
        self._legal_cert_name = None
        self._legal_cert_no = None
        self._notify_email = None
        self._notify_name = None
        self._user_id = None

    @property
    def agent_cert_name(self):
        return self._agent_cert_name

    @agent_cert_name.setter
    def agent_cert_name(self, value):
        self._agent_cert_name = value
    @property
    def agent_cert_no(self):
        return self._agent_cert_no

    @agent_cert_no.setter
    def agent_cert_no(self, value):
        self._agent_cert_no = value
    @property
    def alipay_account(self):
        return self._alipay_account

    @alipay_account.setter
    def alipay_account(self, value):
        self._alipay_account = value
    @property
    def corp_code(self):
        return self._corp_code

    @corp_code.setter
    def corp_code(self, value):
        self._corp_code = value
    @property
    def corp_name(self):
        return self._corp_name

    @corp_name.setter
    def corp_name(self, value):
        self._corp_name = value
    @property
    def corp_type(self):
        return self._corp_type

    @corp_type.setter
    def corp_type(self, value):
        self._corp_type = value
    @property
    def legal_cert_name(self):
        return self._legal_cert_name

    @legal_cert_name.setter
    def legal_cert_name(self, value):
        self._legal_cert_name = value
    @property
    def legal_cert_no(self):
        return self._legal_cert_no

    @legal_cert_no.setter
    def legal_cert_no(self, value):
        self._legal_cert_no = value
    @property
    def notify_email(self):
        return self._notify_email

    @notify_email.setter
    def notify_email(self, value):
        self._notify_email = value
    @property
    def notify_name(self):
        return self._notify_name

    @notify_name.setter
    def notify_name(self, value):
        self._notify_name = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.agent_cert_name:
            if hasattr(self.agent_cert_name, 'to_alipay_dict'):
                params['agent_cert_name'] = self.agent_cert_name.to_alipay_dict()
            else:
                params['agent_cert_name'] = self.agent_cert_name
        if self.agent_cert_no:
            if hasattr(self.agent_cert_no, 'to_alipay_dict'):
                params['agent_cert_no'] = self.agent_cert_no.to_alipay_dict()
            else:
                params['agent_cert_no'] = self.agent_cert_no
        if self.alipay_account:
            if hasattr(self.alipay_account, 'to_alipay_dict'):
                params['alipay_account'] = self.alipay_account.to_alipay_dict()
            else:
                params['alipay_account'] = self.alipay_account
        if self.corp_code:
            if hasattr(self.corp_code, 'to_alipay_dict'):
                params['corp_code'] = self.corp_code.to_alipay_dict()
            else:
                params['corp_code'] = self.corp_code
        if self.corp_name:
            if hasattr(self.corp_name, 'to_alipay_dict'):
                params['corp_name'] = self.corp_name.to_alipay_dict()
            else:
                params['corp_name'] = self.corp_name
        if self.corp_type:
            if hasattr(self.corp_type, 'to_alipay_dict'):
                params['corp_type'] = self.corp_type.to_alipay_dict()
            else:
                params['corp_type'] = self.corp_type
        if self.legal_cert_name:
            if hasattr(self.legal_cert_name, 'to_alipay_dict'):
                params['legal_cert_name'] = self.legal_cert_name.to_alipay_dict()
            else:
                params['legal_cert_name'] = self.legal_cert_name
        if self.legal_cert_no:
            if hasattr(self.legal_cert_no, 'to_alipay_dict'):
                params['legal_cert_no'] = self.legal_cert_no.to_alipay_dict()
            else:
                params['legal_cert_no'] = self.legal_cert_no
        if self.notify_email:
            if hasattr(self.notify_email, 'to_alipay_dict'):
                params['notify_email'] = self.notify_email.to_alipay_dict()
            else:
                params['notify_email'] = self.notify_email
        if self.notify_name:
            if hasattr(self.notify_name, 'to_alipay_dict'):
                params['notify_name'] = self.notify_name.to_alipay_dict()
            else:
                params['notify_name'] = self.notify_name
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CorpEntity()
        if 'agent_cert_name' in d:
            o.agent_cert_name = d['agent_cert_name']
        if 'agent_cert_no' in d:
            o.agent_cert_no = d['agent_cert_no']
        if 'alipay_account' in d:
            o.alipay_account = d['alipay_account']
        if 'corp_code' in d:
            o.corp_code = d['corp_code']
        if 'corp_name' in d:
            o.corp_name = d['corp_name']
        if 'corp_type' in d:
            o.corp_type = d['corp_type']
        if 'legal_cert_name' in d:
            o.legal_cert_name = d['legal_cert_name']
        if 'legal_cert_no' in d:
            o.legal_cert_no = d['legal_cert_no']
        if 'notify_email' in d:
            o.notify_email = d['notify_email']
        if 'notify_name' in d:
            o.notify_name = d['notify_name']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppCodetesttestModel(object):

    def __init__(self):
        self._testparam = None
        self._testtestparam = None

    @property
    def testparam(self):
        return self._testparam

    @testparam.setter
    def testparam(self, value):
        self._testparam = value
    @property
    def testtestparam(self):
        return self._testtestparam

    @testtestparam.setter
    def testtestparam(self, value):
        self._testtestparam = value


    def to_alipay_dict(self):
        params = dict()
        if self.testparam:
            if hasattr(self.testparam, 'to_alipay_dict'):
                params['testparam'] = self.testparam.to_alipay_dict()
            else:
                params['testparam'] = self.testparam
        if self.testtestparam:
            if hasattr(self.testtestparam, 'to_alipay_dict'):
                params['testtestparam'] = self.testtestparam.to_alipay_dict()
            else:
                params['testtestparam'] = self.testtestparam
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppCodetesttestModel()
        if 'testparam' in d:
            o.testparam = d['testparam']
        if 'testtestparam' in d:
            o.testtestparam = d['testtestparam']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankPaymentTradeDepositVerifyMatchModel(object):

    def __init__(self):
        self._amount = None
        self._currency = None
        self._verify_id = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def verify_id(self):
        return self._verify_id

    @verify_id.setter
    def verify_id(self, value):
        self._verify_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = self.currency.to_alipay_dict()
            else:
                params['currency'] = self.currency
        if self.verify_id:
            if hasattr(self.verify_id, 'to_alipay_dict'):
                params['verify_id'] = self.verify_id.to_alipay_dict()
            else:
                params['verify_id'] = self.verify_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankPaymentTradeDepositVerifyMatchModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'currency' in d:
            o.currency = d['currency']
        if 'verify_id' in d:
            o.verify_id = d['verify_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ActivityStat(object):

    def __init__(self):
        self._contract_count = None
        self._finished_count = None
        self._lose_efficacy_count = None
        self._participator_count = None
        self._promising_count = None
        self._trade_count = None
        self._violated_count = None

    @property
    def contract_count(self):
        return self._contract_count

    @contract_count.setter
    def contract_count(self, value):
        self._contract_count = value
    @property
    def finished_count(self):
        return self._finished_count

    @finished_count.setter
    def finished_count(self, value):
        self._finished_count = value
    @property
    def lose_efficacy_count(self):
        return self._lose_efficacy_count

    @lose_efficacy_count.setter
    def lose_efficacy_count(self, value):
        self._lose_efficacy_count = value
    @property
    def participator_count(self):
        return self._participator_count

    @participator_count.setter
    def participator_count(self, value):
        self._participator_count = value
    @property
    def promising_count(self):
        return self._promising_count

    @promising_count.setter
    def promising_count(self, value):
        self._promising_count = value
    @property
    def trade_count(self):
        return self._trade_count

    @trade_count.setter
    def trade_count(self, value):
        self._trade_count = value
    @property
    def violated_count(self):
        return self._violated_count

    @violated_count.setter
    def violated_count(self, value):
        self._violated_count = value


    def to_alipay_dict(self):
        params = dict()
        if self.contract_count:
            if hasattr(self.contract_count, 'to_alipay_dict'):
                params['contract_count'] = self.contract_count.to_alipay_dict()
            else:
                params['contract_count'] = self.contract_count
        if self.finished_count:
            if hasattr(self.finished_count, 'to_alipay_dict'):
                params['finished_count'] = self.finished_count.to_alipay_dict()
            else:
                params['finished_count'] = self.finished_count
        if self.lose_efficacy_count:
            if hasattr(self.lose_efficacy_count, 'to_alipay_dict'):
                params['lose_efficacy_count'] = self.lose_efficacy_count.to_alipay_dict()
            else:
                params['lose_efficacy_count'] = self.lose_efficacy_count
        if self.participator_count:
            if hasattr(self.participator_count, 'to_alipay_dict'):
                params['participator_count'] = self.participator_count.to_alipay_dict()
            else:
                params['participator_count'] = self.participator_count
        if self.promising_count:
            if hasattr(self.promising_count, 'to_alipay_dict'):
                params['promising_count'] = self.promising_count.to_alipay_dict()
            else:
                params['promising_count'] = self.promising_count
        if self.trade_count:
            if hasattr(self.trade_count, 'to_alipay_dict'):
                params['trade_count'] = self.trade_count.to_alipay_dict()
            else:
                params['trade_count'] = self.trade_count
        if self.violated_count:
            if hasattr(self.violated_count, 'to_alipay_dict'):
                params['violated_count'] = self.violated_count.to_alipay_dict()
            else:
                params['violated_count'] = self.violated_count
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ActivityStat()
        if 'contract_count' in d:
            o.contract_count = d['contract_count']
        if 'finished_count' in d:
            o.finished_count = d['finished_count']
        if 'lose_efficacy_count' in d:
            o.lose_efficacy_count = d['lose_efficacy_count']
        if 'participator_count' in d:
            o.participator_count = d['participator_count']
        if 'promising_count' in d:
            o.promising_count = d['promising_count']
        if 'trade_count' in d:
            o.trade_count = d['trade_count']
        if 'violated_count' in d:
            o.violated_count = d['violated_count']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZMGoOutDiscountInfo(object):

    def __init__(self):
        self._discount_amount = None
        self._discount_name = None
        self._discount_type = None

    @property
    def discount_amount(self):
        return self._discount_amount

    @discount_amount.setter
    def discount_amount(self, value):
        self._discount_amount = value
    @property
    def discount_name(self):
        return self._discount_name

    @discount_name.setter
    def discount_name(self, value):
        self._discount_name = value
    @property
    def discount_type(self):
        return self._discount_type

    @discount_type.setter
    def discount_type(self, value):
        self._discount_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.discount_amount:
            if hasattr(self.discount_amount, 'to_alipay_dict'):
                params['discount_amount'] = self.discount_amount.to_alipay_dict()
            else:
                params['discount_amount'] = self.discount_amount
        if self.discount_name:
            if hasattr(self.discount_name, 'to_alipay_dict'):
                params['discount_name'] = self.discount_name.to_alipay_dict()
            else:
                params['discount_name'] = self.discount_name
        if self.discount_type:
            if hasattr(self.discount_type, 'to_alipay_dict'):
                params['discount_type'] = self.discount_type.to_alipay_dict()
            else:
                params['discount_type'] = self.discount_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZMGoOutDiscountInfo()
        if 'discount_amount' in d:
            o.discount_amount = d['discount_amount']
        if 'discount_name' in d:
            o.discount_name = d['discount_name']
        if 'discount_type' in d:
            o.discount_type = d['discount_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AcquireOrder import AcquireOrder
from alipay.aop.api.domain.FundOrder import FundOrder


class AnttechBlockchainDefinSaasPaymentCreateModel(object):

    def __init__(self):
        self._acquire_order = None
        self._fund_mode = None
        self._fund_order = None
        self._order_type = None
        self._out_request_id = None
        self._platform_member_id = None

    @property
    def acquire_order(self):
        return self._acquire_order

    @acquire_order.setter
    def acquire_order(self, value):
        if isinstance(value, AcquireOrder):
            self._acquire_order = value
        else:
            self._acquire_order = AcquireOrder.from_alipay_dict(value)
    @property
    def fund_mode(self):
        return self._fund_mode

    @fund_mode.setter
    def fund_mode(self, value):
        self._fund_mode = value
    @property
    def fund_order(self):
        return self._fund_order

    @fund_order.setter
    def fund_order(self, value):
        if isinstance(value, FundOrder):
            self._fund_order = value
        else:
            self._fund_order = FundOrder.from_alipay_dict(value)
    @property
    def order_type(self):
        return self._order_type

    @order_type.setter
    def order_type(self, value):
        self._order_type = value
    @property
    def out_request_id(self):
        return self._out_request_id

    @out_request_id.setter
    def out_request_id(self, value):
        self._out_request_id = value
    @property
    def platform_member_id(self):
        return self._platform_member_id

    @platform_member_id.setter
    def platform_member_id(self, value):
        self._platform_member_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.acquire_order:
            if hasattr(self.acquire_order, 'to_alipay_dict'):
                params['acquire_order'] = self.acquire_order.to_alipay_dict()
            else:
                params['acquire_order'] = self.acquire_order
        if self.fund_mode:
            if hasattr(self.fund_mode, 'to_alipay_dict'):
                params['fund_mode'] = self.fund_mode.to_alipay_dict()
            else:
                params['fund_mode'] = self.fund_mode
        if self.fund_order:
            if hasattr(self.fund_order, 'to_alipay_dict'):
                params['fund_order'] = self.fund_order.to_alipay_dict()
            else:
                params['fund_order'] = self.fund_order
        if self.order_type:
            if hasattr(self.order_type, 'to_alipay_dict'):
                params['order_type'] = self.order_type.to_alipay_dict()
            else:
                params['order_type'] = self.order_type
        if self.out_request_id:
            if hasattr(self.out_request_id, 'to_alipay_dict'):
                params['out_request_id'] = self.out_request_id.to_alipay_dict()
            else:
                params['out_request_id'] = self.out_request_id
        if self.platform_member_id:
            if hasattr(self.platform_member_id, 'to_alipay_dict'):
                params['platform_member_id'] = self.platform_member_id.to_alipay_dict()
            else:
                params['platform_member_id'] = self.platform_member_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainDefinSaasPaymentCreateModel()
        if 'acquire_order' in d:
            o.acquire_order = d['acquire_order']
        if 'fund_mode' in d:
            o.fund_mode = d['fund_mode']
        if 'fund_order' in d:
            o.fund_order = d['fund_order']
        if 'order_type' in d:
            o.order_type = d['order_type']
        if 'out_request_id' in d:
            o.out_request_id = d['out_request_id']
        if 'platform_member_id' in d:
            o.platform_member_id = d['platform_member_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PaidOuterCardCycleSellConfDTO(object):

    def __init__(self):
        self._cycle_selling_url = None
        self._cycle_type = None
        self._support_cycle_sell = None

    @property
    def cycle_selling_url(self):
        return self._cycle_selling_url

    @cycle_selling_url.setter
    def cycle_selling_url(self, value):
        self._cycle_selling_url = value
    @property
    def cycle_type(self):
        return self._cycle_type

    @cycle_type.setter
    def cycle_type(self, value):
        if isinstance(value, list):
            self._cycle_type = list()
            for i in value:
                self._cycle_type.append(i)
    @property
    def support_cycle_sell(self):
        return self._support_cycle_sell

    @support_cycle_sell.setter
    def support_cycle_sell(self, value):
        self._support_cycle_sell = value


    def to_alipay_dict(self):
        params = dict()
        if self.cycle_selling_url:
            if hasattr(self.cycle_selling_url, 'to_alipay_dict'):
                params['cycle_selling_url'] = self.cycle_selling_url.to_alipay_dict()
            else:
                params['cycle_selling_url'] = self.cycle_selling_url
        if self.cycle_type:
            if isinstance(self.cycle_type, list):
                for i in range(0, len(self.cycle_type)):
                    element = self.cycle_type[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.cycle_type[i] = element.to_alipay_dict()
            if hasattr(self.cycle_type, 'to_alipay_dict'):
                params['cycle_type'] = self.cycle_type.to_alipay_dict()
            else:
                params['cycle_type'] = self.cycle_type
        if self.support_cycle_sell:
            if hasattr(self.support_cycle_sell, 'to_alipay_dict'):
                params['support_cycle_sell'] = self.support_cycle_sell.to_alipay_dict()
            else:
                params['support_cycle_sell'] = self.support_cycle_sell
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaidOuterCardCycleSellConfDTO()
        if 'cycle_selling_url' in d:
            o.cycle_selling_url = d['cycle_selling_url']
        if 'cycle_type' in d:
            o.cycle_type = d['cycle_type']
        if 'support_cycle_sell' in d:
            o.support_cycle_sell = d['support_cycle_sell']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ServicePromoBaseVO import ServicePromoBaseVO
from alipay.aop.api.domain.ServicePromoBaseVO import ServicePromoBaseVO


class AlipayOpenAppServicePromoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAppServicePromoQueryResponse, self).__init__()
        self._editing_service_promo = None
        self._valid_service_promo = None

    @property
    def editing_service_promo(self):
        return self._editing_service_promo

    @editing_service_promo.setter
    def editing_service_promo(self, value):
        if isinstance(value, ServicePromoBaseVO):
            self._editing_service_promo = value
        else:
            self._editing_service_promo = ServicePromoBaseVO.from_alipay_dict(value)
    @property
    def valid_service_promo(self):
        return self._valid_service_promo

    @valid_service_promo.setter
    def valid_service_promo(self, value):
        if isinstance(value, ServicePromoBaseVO):
            self._valid_service_promo = value
        else:
            self._valid_service_promo = ServicePromoBaseVO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAppServicePromoQueryResponse, self).parse_response_content(response_content)
        if 'editing_service_promo' in response:
            self.editing_service_promo = response['editing_service_promo']
        if 'valid_service_promo' in response:
            self.valid_service_promo = response['valid_service_promo']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class UnfreezeOrderDetail(object):

    def __init__(self):
        self._alipay_order_no = None
        self._create_time = None
        self._memo = None
        self._merchant_order_no = None
        self._modified_time = None
        self._order_amount = None
        self._order_status = None
        self._unfreeze_amount = None

    @property
    def alipay_order_no(self):
        return self._alipay_order_no

    @alipay_order_no.setter
    def alipay_order_no(self, value):
        self._alipay_order_no = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def merchant_order_no(self):
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, value):
        self._merchant_order_no = value
    @property
    def modified_time(self):
        return self._modified_time

    @modified_time.setter
    def modified_time(self, value):
        self._modified_time = value
    @property
    def order_amount(self):
        return self._order_amount

    @order_amount.setter
    def order_amount(self, value):
        self._order_amount = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def unfreeze_amount(self):
        return self._unfreeze_amount

    @unfreeze_amount.setter
    def unfreeze_amount(self, value):
        self._unfreeze_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_order_no:
            if hasattr(self.alipay_order_no, 'to_alipay_dict'):
                params['alipay_order_no'] = self.alipay_order_no.to_alipay_dict()
            else:
                params['alipay_order_no'] = self.alipay_order_no
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.merchant_order_no:
            if hasattr(self.merchant_order_no, 'to_alipay_dict'):
                params['merchant_order_no'] = self.merchant_order_no.to_alipay_dict()
            else:
                params['merchant_order_no'] = self.merchant_order_no
        if self.modified_time:
            if hasattr(self.modified_time, 'to_alipay_dict'):
                params['modified_time'] = self.modified_time.to_alipay_dict()
            else:
                params['modified_time'] = self.modified_time
        if self.order_amount:
            if hasattr(self.order_amount, 'to_alipay_dict'):
                params['order_amount'] = self.order_amount.to_alipay_dict()
            else:
                params['order_amount'] = self.order_amount
        if self.order_status:
            if hasattr(self.order_status, 'to_alipay_dict'):
                params['order_status'] = self.order_status.to_alipay_dict()
            else:
                params['order_status'] = self.order_status
        if self.unfreeze_amount:
            if hasattr(self.unfreeze_amount, 'to_alipay_dict'):
                params['unfreeze_amount'] = self.unfreeze_amount.to_alipay_dict()
            else:
                params['unfreeze_amount'] = self.unfreeze_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UnfreezeOrderDetail()
        if 'alipay_order_no' in d:
            o.alipay_order_no = d['alipay_order_no']
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'memo' in d:
            o.memo = d['memo']
        if 'merchant_order_no' in d:
            o.merchant_order_no = d['merchant_order_no']
        if 'modified_time' in d:
            o.modified_time = d['modified_time']
        if 'order_amount' in d:
            o.order_amount = d['order_amount']
        if 'order_status' in d:
            o.order_status = d['order_status']
        if 'unfreeze_amount' in d:
            o.unfreeze_amount = d['unfreeze_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MerchantApplyResultRecord import MerchantApplyResultRecord


class AntMerchantExpandMapplyorderQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandMapplyorderQueryResponse, self).__init__()
        self._order_no = None
        self._order_status = None
        self._out_biz_no = None
        self._result_info = None

    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def result_info(self):
        return self._result_info

    @result_info.setter
    def result_info(self, value):
        if isinstance(value, list):
            self._result_info = list()
            for i in value:
                if isinstance(i, MerchantApplyResultRecord):
                    self._result_info.append(i)
                else:
                    self._result_info.append(MerchantApplyResultRecord.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandMapplyorderQueryResponse, self).parse_response_content(response_content)
        if 'order_no' in response:
            self.order_no = response['order_no']
        if 'order_status' in response:
            self.order_status = response['order_status']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'result_info' in response:
            self.result_info = response['result_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossFncApbillBillcustviewBatchqueryModel(object):

    def __init__(self):
        self._bill_nos = None
        self._invoice_type = None

    @property
    def bill_nos(self):
        return self._bill_nos

    @bill_nos.setter
    def bill_nos(self, value):
        if isinstance(value, list):
            self._bill_nos = list()
            for i in value:
                self._bill_nos.append(i)
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_nos:
            if isinstance(self.bill_nos, list):
                for i in range(0, len(self.bill_nos)):
                    element = self.bill_nos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.bill_nos[i] = element.to_alipay_dict()
            if hasattr(self.bill_nos, 'to_alipay_dict'):
                params['bill_nos'] = self.bill_nos.to_alipay_dict()
            else:
                params['bill_nos'] = self.bill_nos
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncApbillBillcustviewBatchqueryModel()
        if 'bill_nos' in d:
            o.bill_nos = d['bill_nos']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayZdatafrontCommonQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayZdatafrontCommonQueryResponse, self).__init__()
        self._cache_timestamp = None
        self._values = None

    @property
    def cache_timestamp(self):
        return self._cache_timestamp

    @cache_timestamp.setter
    def cache_timestamp(self, value):
        self._cache_timestamp = value
    @property
    def values(self):
        return self._values

    @values.setter
    def values(self, value):
        self._values = value

    def parse_response_content(self, response_content):
        response = super(AlipayZdatafrontCommonQueryResponse, self).parse_response_content(response_content)
        if 'cache_timestamp' in response:
            self.cache_timestamp = response['cache_timestamp']
        if 'values' in response:
            self.values = response['values']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditSupplychainFactoringSupplierCreateModel(object):

    def __init__(self):
        self._buyer_ip_id = None
        self._buyer_ip_role_id = None
        self._buyer_site = None
        self._buyer_site_user_id = None
        self._merchant_id = None
        self._operator_name = None
        self._rcv_account_type = None
        self._seller_bank_acc = None
        self._seller_bank_acc_name = None
        self._seller_bank_branch_union_code = None
        self._seller_bank_name = None
        self._seller_contact_email = None
        self._seller_contact_name = None
        self._seller_contact_phone = None
        self._seller_login_id = None
        self._store_city = None
        self._store_county = None
        self._store_name = None
        self._store_no = None
        self._store_province = None
        self._store_subject_cert_no = None
        self._store_subject_name = None

    @property
    def buyer_ip_id(self):
        return self._buyer_ip_id

    @buyer_ip_id.setter
    def buyer_ip_id(self, value):
        self._buyer_ip_id = value
    @property
    def buyer_ip_role_id(self):
        return self._buyer_ip_role_id

    @buyer_ip_role_id.setter
    def buyer_ip_role_id(self, value):
        self._buyer_ip_role_id = value
    @property
    def buyer_site(self):
        return self._buyer_site

    @buyer_site.setter
    def buyer_site(self, value):
        self._buyer_site = value
    @property
    def buyer_site_user_id(self):
        return self._buyer_site_user_id

    @buyer_site_user_id.setter
    def buyer_site_user_id(self, value):
        self._buyer_site_user_id = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def operator_name(self):
        return self._operator_name

    @operator_name.setter
    def operator_name(self, value):
        self._operator_name = value
    @property
    def rcv_account_type(self):
        return self._rcv_account_type

    @rcv_account_type.setter
    def rcv_account_type(self, value):
        self._rcv_account_type = value
    @property
    def seller_bank_acc(self):
        return self._seller_bank_acc

    @seller_bank_acc.setter
    def seller_bank_acc(self, value):
        self._seller_bank_acc = value
    @property
    def seller_bank_acc_name(self):
        return self._seller_bank_acc_name

    @seller_bank_acc_name.setter
    def seller_bank_acc_name(self, value):
        self._seller_bank_acc_name = value
    @property
    def seller_bank_branch_union_code(self):
        return self._seller_bank_branch_union_code

    @seller_bank_branch_union_code.setter
    def seller_bank_branch_union_code(self, value):
        self._seller_bank_branch_union_code = value
    @property
    def seller_bank_name(self):
        return self._seller_bank_name

    @seller_bank_name.setter
    def seller_bank_name(self, value):
        self._seller_bank_name = value
    @property
    def seller_contact_email(self):
        return self._seller_contact_email

    @seller_contact_email.setter
    def seller_contact_email(self, value):
        self._seller_contact_email = value
    @property
    def seller_contact_name(self):
        return self._seller_contact_name

    @seller_contact_name.setter
    def seller_contact_name(self, value):
        self._seller_contact_name = value
    @property
    def seller_contact_phone(self):
        return self._seller_contact_phone

    @seller_contact_phone.setter
    def seller_contact_phone(self, value):
        self._seller_contact_phone = value
    @property
    def seller_login_id(self):
        return self._seller_login_id

    @seller_login_id.setter
    def seller_login_id(self, value):
        self._seller_login_id = value
    @property
    def store_city(self):
        return self._store_city

    @store_city.setter
    def store_city(self, value):
        self._store_city = value
    @property
    def store_county(self):
        return self._store_county

    @store_county.setter
    def store_county(self, value):
        self._store_county = value
    @property
    def store_name(self):
        return self._store_name

    @store_name.setter
    def store_name(self, value):
        self._store_name = value
    @property
    def store_no(self):
        return self._store_no

    @store_no.setter
    def store_no(self, value):
        self._store_no = value
    @property
    def store_province(self):
        return self._store_province

    @store_province.setter
    def store_province(self, value):
        self._store_province = value
    @property
    def store_subject_cert_no(self):
        return self._store_subject_cert_no

    @store_subject_cert_no.setter
    def store_subject_cert_no(self, value):
        self._store_subject_cert_no = value
    @property
    def store_subject_name(self):
        return self._store_subject_name

    @store_subject_name.setter
    def store_subject_name(self, value):
        self._store_subject_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.buyer_ip_id:
            if hasattr(self.buyer_ip_id, 'to_alipay_dict'):
                params['buyer_ip_id'] = self.buyer_ip_id.to_alipay_dict()
            else:
                params['buyer_ip_id'] = self.buyer_ip_id
        if self.buyer_ip_role_id:
            if hasattr(self.buyer_ip_role_id, 'to_alipay_dict'):
                params['buyer_ip_role_id'] = self.buyer_ip_role_id.to_alipay_dict()
            else:
                params['buyer_ip_role_id'] = self.buyer_ip_role_id
        if self.buyer_site:
            if hasattr(self.buyer_site, 'to_alipay_dict'):
                params['buyer_site'] = self.buyer_site.to_alipay_dict()
            else:
                params['buyer_site'] = self.buyer_site
        if self.buyer_site_user_id:
            if hasattr(self.buyer_site_user_id, 'to_alipay_dict'):
                params['buyer_site_user_id'] = self.buyer_site_user_id.to_alipay_dict()
            else:
                params['buyer_site_user_id'] = self.buyer_site_user_id
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.operator_name:
            if hasattr(self.operator_name, 'to_alipay_dict'):
                params['operator_name'] = self.operator_name.to_alipay_dict()
            else:
                params['operator_name'] = self.operator_name
        if self.rcv_account_type:
            if hasattr(self.rcv_account_type, 'to_alipay_dict'):
                params['rcv_account_type'] = self.rcv_account_type.to_alipay_dict()
            else:
                params['rcv_account_type'] = self.rcv_account_type
        if self.seller_bank_acc:
            if hasattr(self.seller_bank_acc, 'to_alipay_dict'):
                params['seller_bank_acc'] = self.seller_bank_acc.to_alipay_dict()
            else:
                params['seller_bank_acc'] = self.seller_bank_acc
        if self.seller_bank_acc_name:
            if hasattr(self.seller_bank_acc_name, 'to_alipay_dict'):
                params['seller_bank_acc_name'] = self.seller_bank_acc_name.to_alipay_dict()
            else:
                params['seller_bank_acc_name'] = self.seller_bank_acc_name
        if self.seller_bank_branch_union_code:
            if hasattr(self.seller_bank_branch_union_code, 'to_alipay_dict'):
                params['seller_bank_branch_union_code'] = self.seller_bank_branch_union_code.to_alipay_dict()
            else:
                params['seller_bank_branch_union_code'] = self.seller_bank_branch_union_code
        if self.seller_bank_name:
            if hasattr(self.seller_bank_name, 'to_alipay_dict'):
                params['seller_bank_name'] = self.seller_bank_name.to_alipay_dict()
            else:
                params['seller_bank_name'] = self.seller_bank_name
        if self.seller_contact_email:
            if hasattr(self.seller_contact_email, 'to_alipay_dict'):
                params['seller_contact_email'] = self.seller_contact_email.to_alipay_dict()
            else:
                params['seller_contact_email'] = self.seller_contact_email
        if self.seller_contact_name:
            if hasattr(self.seller_contact_name, 'to_alipay_dict'):
                params['seller_contact_name'] = self.seller_contact_name.to_alipay_dict()
            else:
                params['seller_contact_name'] = self.seller_contact_name
        if self.seller_contact_phone:
            if hasattr(self.seller_contact_phone, 'to_alipay_dict'):
                params['seller_contact_phone'] = self.seller_contact_phone.to_alipay_dict()
            else:
                params['seller_contact_phone'] = self.seller_contact_phone
        if self.seller_login_id:
            if hasattr(self.seller_login_id, 'to_alipay_dict'):
                params['seller_login_id'] = self.seller_login_id.to_alipay_dict()
            else:
                params['seller_login_id'] = self.seller_login_id
        if self.store_city:
            if hasattr(self.store_city, 'to_alipay_dict'):
                params['store_city'] = self.store_city.to_alipay_dict()
            else:
                params['store_city'] = self.store_city
        if self.store_county:
            if hasattr(self.store_county, 'to_alipay_dict'):
                params['store_county'] = self.store_county.to_alipay_dict()
            else:
                params['store_county'] = self.store_county
        if self.store_name:
            if hasattr(self.store_name, 'to_alipay_dict'):
                params['store_name'] = self.store_name.to_alipay_dict()
            else:
                params['store_name'] = self.store_name
        if self.store_no:
            if hasattr(self.store_no, 'to_alipay_dict'):
                params['store_no'] = self.store_no.to_alipay_dict()
            else:
                params['store_no'] = self.store_no
        if self.store_province:
            if hasattr(self.store_province, 'to_alipay_dict'):
                params['store_province'] = self.store_province.to_alipay_dict()
            else:
                params['store_province'] = self.store_province
        if self.store_subject_cert_no:
            if hasattr(self.store_subject_cert_no, 'to_alipay_dict'):
                params['store_subject_cert_no'] = self.store_subject_cert_no.to_alipay_dict()
            else:
                params['store_subject_cert_no'] = self.store_subject_cert_no
        if self.store_subject_name:
            if hasattr(self.store_subject_name, 'to_alipay_dict'):
                params['store_subject_name'] = self.store_subject_name.to_alipay_dict()
            else:
                params['store_subject_name'] = self.store_subject_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditSupplychainFactoringSupplierCreateModel()
        if 'buyer_ip_id' in d:
            o.buyer_ip_id = d['buyer_ip_id']
        if 'buyer_ip_role_id' in d:
            o.buyer_ip_role_id = d['buyer_ip_role_id']
        if 'buyer_site' in d:
            o.buyer_site = d['buyer_site']
        if 'buyer_site_user_id' in d:
            o.buyer_site_user_id = d['buyer_site_user_id']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'operator_name' in d:
            o.operator_name = d['operator_name']
        if 'rcv_account_type' in d:
            o.rcv_account_type = d['rcv_account_type']
        if 'seller_bank_acc' in d:
            o.seller_bank_acc = d['seller_bank_acc']
        if 'seller_bank_acc_name' in d:
            o.seller_bank_acc_name = d['seller_bank_acc_name']
        if 'seller_bank_branch_union_code' in d:
            o.seller_bank_branch_union_code = d['seller_bank_branch_union_code']
        if 'seller_bank_name' in d:
            o.seller_bank_name = d['seller_bank_name']
        if 'seller_contact_email' in d:
            o.seller_contact_email = d['seller_contact_email']
        if 'seller_contact_name' in d:
            o.seller_contact_name = d['seller_contact_name']
        if 'seller_contact_phone' in d:
            o.seller_contact_phone = d['seller_contact_phone']
        if 'seller_login_id' in d:
            o.seller_login_id = d['seller_login_id']
        if 'store_city' in d:
            o.store_city = d['store_city']
        if 'store_county' in d:
            o.store_county = d['store_county']
        if 'store_name' in d:
            o.store_name = d['store_name']
        if 'store_no' in d:
            o.store_no = d['store_no']
        if 'store_province' in d:
            o.store_province = d['store_province']
        if 'store_subject_cert_no' in d:
            o.store_subject_cert_no = d['store_subject_cert_no']
        if 'store_subject_name' in d:
            o.store_subject_name = d['store_subject_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechBlockchainDefinAssetmanagePenetrateQueryResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainDefinAssetmanagePenetrateQueryResponse, self).__init__()
        self._error_code = None
        self._error_msg = None
        self._error_view_msg = None
        self._result_obj = None

    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_msg(self):
        return self._error_msg

    @error_msg.setter
    def error_msg(self, value):
        self._error_msg = value
    @property
    def error_view_msg(self):
        return self._error_view_msg

    @error_view_msg.setter
    def error_view_msg(self, value):
        self._error_view_msg = value
    @property
    def result_obj(self):
        return self._result_obj

    @result_obj.setter
    def result_obj(self, value):
        self._result_obj = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainDefinAssetmanagePenetrateQueryResponse, self).parse_response_content(response_content)
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'error_msg' in response:
            self.error_msg = response['error_msg']
        if 'error_view_msg' in response:
            self.error_view_msg = response['error_view_msg']
        if 'result_obj' in response:
            self.result_obj = response['result_obj']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppSmsgDataSyncModel(object):

    def __init__(self):
        self._data_one = None
        self._data_two = None

    @property
    def data_one(self):
        return self._data_one

    @data_one.setter
    def data_one(self, value):
        self._data_one = value
    @property
    def data_two(self):
        return self._data_two

    @data_two.setter
    def data_two(self, value):
        self._data_two = value


    def to_alipay_dict(self):
        params = dict()
        if self.data_one:
            if hasattr(self.data_one, 'to_alipay_dict'):
                params['data_one'] = self.data_one.to_alipay_dict()
            else:
                params['data_one'] = self.data_one
        if self.data_two:
            if hasattr(self.data_two, 'to_alipay_dict'):
                params['data_two'] = self.data_two.to_alipay_dict()
            else:
                params['data_two'] = self.data_two
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppSmsgDataSyncModel()
        if 'data_one' in d:
            o.data_one = d['data_one']
        if 'data_two' in d:
            o.data_two = d['data_two']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserElectronicidUserQueryModel(object):

    def __init__(self):
        self._barcode = None

    @property
    def barcode(self):
        return self._barcode

    @barcode.setter
    def barcode(self, value):
        self._barcode = value


    def to_alipay_dict(self):
        params = dict()
        if self.barcode:
            if hasattr(self.barcode, 'to_alipay_dict'):
                params['barcode'] = self.barcode.to_alipay_dict()
            else:
                params['barcode'] = self.barcode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserElectronicidUserQueryModel()
        if 'barcode' in d:
            o.barcode = d['barcode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Dishes import Dishes


class KoubeiCateringDishRecommendQueryModel(object):

    def __init__(self):
        self._dish_id = None
        self._dish_list = None
        self._merchent_pid = None
        self._people = None
        self._per_price = None
        self._shop_id = None
        self._type = None
        self._user_id = None

    @property
    def dish_id(self):
        return self._dish_id

    @dish_id.setter
    def dish_id(self, value):
        self._dish_id = value
    @property
    def dish_list(self):
        return self._dish_list

    @dish_list.setter
    def dish_list(self, value):
        if isinstance(value, list):
            self._dish_list = list()
            for i in value:
                if isinstance(i, Dishes):
                    self._dish_list.append(i)
                else:
                    self._dish_list.append(Dishes.from_alipay_dict(i))
    @property
    def merchent_pid(self):
        return self._merchent_pid

    @merchent_pid.setter
    def merchent_pid(self, value):
        self._merchent_pid = value
    @property
    def people(self):
        return self._people

    @people.setter
    def people(self, value):
        self._people = value
    @property
    def per_price(self):
        return self._per_price

    @per_price.setter
    def per_price(self, value):
        self._per_price = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.dish_id:
            if hasattr(self.dish_id, 'to_alipay_dict'):
                params['dish_id'] = self.dish_id.to_alipay_dict()
            else:
                params['dish_id'] = self.dish_id
        if self.dish_list:
            if isinstance(self.dish_list, list):
                for i in range(0, len(self.dish_list)):
                    element = self.dish_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.dish_list[i] = element.to_alipay_dict()
            if hasattr(self.dish_list, 'to_alipay_dict'):
                params['dish_list'] = self.dish_list.to_alipay_dict()
            else:
                params['dish_list'] = self.dish_list
        if self.merchent_pid:
            if hasattr(self.merchent_pid, 'to_alipay_dict'):
                params['merchent_pid'] = self.merchent_pid.to_alipay_dict()
            else:
                params['merchent_pid'] = self.merchent_pid
        if self.people:
            if hasattr(self.people, 'to_alipay_dict'):
                params['people'] = self.people.to_alipay_dict()
            else:
                params['people'] = self.people
        if self.per_price:
            if hasattr(self.per_price, 'to_alipay_dict'):
                params['per_price'] = self.per_price.to_alipay_dict()
            else:
                params['per_price'] = self.per_price
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishRecommendQueryModel()
        if 'dish_id' in d:
            o.dish_id = d['dish_id']
        if 'dish_list' in d:
            o.dish_list = d['dish_list']
        if 'merchent_pid' in d:
            o.merchent_pid = d['merchent_pid']
        if 'people' in d:
            o.people = d['people']
        if 'per_price' in d:
            o.per_price = d['per_price']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'type' in d:
            o.type = d['type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InstallmentDetail import InstallmentDetail


class AnttechBlockchainFinanceTruspleLoanrepaySubmitModel(object):

    def __init__(self):
        self._actual_repaid_amount = None
        self._external_loan_id = None
        self._external_repay_request_id = None
        self._external_user_id = None
        self._fund_channel = None
        self._fund_message = None
        self._inst_code = None
        self._installment_details = None
        self._repay_amount_currency = None
        self._repay_time = None
        self._repay_type = None

    @property
    def actual_repaid_amount(self):
        return self._actual_repaid_amount

    @actual_repaid_amount.setter
    def actual_repaid_amount(self, value):
        self._actual_repaid_amount = value
    @property
    def external_loan_id(self):
        return self._external_loan_id

    @external_loan_id.setter
    def external_loan_id(self, value):
        self._external_loan_id = value
    @property
    def external_repay_request_id(self):
        return self._external_repay_request_id

    @external_repay_request_id.setter
    def external_repay_request_id(self, value):
        self._external_repay_request_id = value
    @property
    def external_user_id(self):
        return self._external_user_id

    @external_user_id.setter
    def external_user_id(self, value):
        self._external_user_id = value
    @property
    def fund_channel(self):
        return self._fund_channel

    @fund_channel.setter
    def fund_channel(self, value):
        self._fund_channel = value
    @property
    def fund_message(self):
        return self._fund_message

    @fund_message.setter
    def fund_message(self, value):
        self._fund_message = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def installment_details(self):
        return self._installment_details

    @installment_details.setter
    def installment_details(self, value):
        if isinstance(value, list):
            self._installment_details = list()
            for i in value:
                if isinstance(i, InstallmentDetail):
                    self._installment_details.append(i)
                else:
                    self._installment_details.append(InstallmentDetail.from_alipay_dict(i))
    @property
    def repay_amount_currency(self):
        return self._repay_amount_currency

    @repay_amount_currency.setter
    def repay_amount_currency(self, value):
        self._repay_amount_currency = value
    @property
    def repay_time(self):
        return self._repay_time

    @repay_time.setter
    def repay_time(self, value):
        self._repay_time = value
    @property
    def repay_type(self):
        return self._repay_type

    @repay_type.setter
    def repay_type(self, value):
        self._repay_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.actual_repaid_amount:
            if hasattr(self.actual_repaid_amount, 'to_alipay_dict'):
                params['actual_repaid_amount'] = self.actual_repaid_amount.to_alipay_dict()
            else:
                params['actual_repaid_amount'] = self.actual_repaid_amount
        if self.external_loan_id:
            if hasattr(self.external_loan_id, 'to_alipay_dict'):
                params['external_loan_id'] = self.external_loan_id.to_alipay_dict()
            else:
                params['external_loan_id'] = self.external_loan_id
        if self.external_repay_request_id:
            if hasattr(self.external_repay_request_id, 'to_alipay_dict'):
                params['external_repay_request_id'] = self.external_repay_request_id.to_alipay_dict()
            else:
                params['external_repay_request_id'] = self.external_repay_request_id
        if self.external_user_id:
            if hasattr(self.external_user_id, 'to_alipay_dict'):
                params['external_user_id'] = self.external_user_id.to_alipay_dict()
            else:
                params['external_user_id'] = self.external_user_id
        if self.fund_channel:
            if hasattr(self.fund_channel, 'to_alipay_dict'):
                params['fund_channel'] = self.fund_channel.to_alipay_dict()
            else:
                params['fund_channel'] = self.fund_channel
        if self.fund_message:
            if hasattr(self.fund_message, 'to_alipay_dict'):
                params['fund_message'] = self.fund_message.to_alipay_dict()
            else:
                params['fund_message'] = self.fund_message
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.installment_details:
            if isinstance(self.installment_details, list):
                for i in range(0, len(self.installment_details)):
                    element = self.installment_details[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.installment_details[i] = element.to_alipay_dict()
            if hasattr(self.installment_details, 'to_alipay_dict'):
                params['installment_details'] = self.installment_details.to_alipay_dict()
            else:
                params['installment_details'] = self.installment_details
        if self.repay_amount_currency:
            if hasattr(self.repay_amount_currency, 'to_alipay_dict'):
                params['repay_amount_currency'] = self.repay_amount_currency.to_alipay_dict()
            else:
                params['repay_amount_currency'] = self.repay_amount_currency
        if self.repay_time:
            if hasattr(self.repay_time, 'to_alipay_dict'):
                params['repay_time'] = self.repay_time.to_alipay_dict()
            else:
                params['repay_time'] = self.repay_time
        if self.repay_type:
            if hasattr(self.repay_type, 'to_alipay_dict'):
                params['repay_type'] = self.repay_type.to_alipay_dict()
            else:
                params['repay_type'] = self.repay_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainFinanceTruspleLoanrepaySubmitModel()
        if 'actual_repaid_amount' in d:
            o.actual_repaid_amount = d['actual_repaid_amount']
        if 'external_loan_id' in d:
            o.external_loan_id = d['external_loan_id']
        if 'external_repay_request_id' in d:
            o.external_repay_request_id = d['external_repay_request_id']
        if 'external_user_id' in d:
            o.external_user_id = d['external_user_id']
        if 'fund_channel' in d:
            o.fund_channel = d['fund_channel']
        if 'fund_message' in d:
            o.fund_message = d['fund_message']
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'installment_details' in d:
            o.installment_details = d['installment_details']
        if 'repay_amount_currency' in d:
            o.repay_amount_currency = d['repay_amount_currency']
        if 'repay_time' in d:
            o.repay_time = d['repay_time']
        if 'repay_type' in d:
            o.repay_type = d['repay_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataPrinterTaskSubmitModel(object):

    def __init__(self):
        self._access_token = None
        self._client_id = None
        self._client_secret = None
        self._content = None
        self._device_sn = None
        self._origin_id = None

    @property
    def access_token(self):
        return self._access_token

    @access_token.setter
    def access_token(self, value):
        self._access_token = value
    @property
    def client_id(self):
        return self._client_id

    @client_id.setter
    def client_id(self, value):
        self._client_id = value
    @property
    def client_secret(self):
        return self._client_secret

    @client_secret.setter
    def client_secret(self, value):
        self._client_secret = value
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def device_sn(self):
        return self._device_sn

    @device_sn.setter
    def device_sn(self, value):
        self._device_sn = value
    @property
    def origin_id(self):
        return self._origin_id

    @origin_id.setter
    def origin_id(self, value):
        self._origin_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.access_token:
            if hasattr(self.access_token, 'to_alipay_dict'):
                params['access_token'] = self.access_token.to_alipay_dict()
            else:
                params['access_token'] = self.access_token
        if self.client_id:
            if hasattr(self.client_id, 'to_alipay_dict'):
                params['client_id'] = self.client_id.to_alipay_dict()
            else:
                params['client_id'] = self.client_id
        if self.client_secret:
            if hasattr(self.client_secret, 'to_alipay_dict'):
                params['client_secret'] = self.client_secret.to_alipay_dict()
            else:
                params['client_secret'] = self.client_secret
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.device_sn:
            if hasattr(self.device_sn, 'to_alipay_dict'):
                params['device_sn'] = self.device_sn.to_alipay_dict()
            else:
                params['device_sn'] = self.device_sn
        if self.origin_id:
            if hasattr(self.origin_id, 'to_alipay_dict'):
                params['origin_id'] = self.origin_id.to_alipay_dict()
            else:
                params['origin_id'] = self.origin_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataPrinterTaskSubmitModel()
        if 'access_token' in d:
            o.access_token = d['access_token']
        if 'client_id' in d:
            o.client_id = d['client_id']
        if 'client_secret' in d:
            o.client_secret = d['client_secret']
        if 'content' in d:
            o.content = d['content']
        if 'device_sn' in d:
            o.device_sn = d['device_sn']
        if 'origin_id' in d:
            o.origin_id = d['origin_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class SubAccountBalanceOpenApiDTO(object):

    def __init__(self):
        self._available_amount = None
        self._balance = None
        self._freeze_amount = None

    @property
    def available_amount(self):
        return self._available_amount

    @available_amount.setter
    def available_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._available_amount = value
        else:
            self._available_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._balance = value
        else:
            self._balance = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def freeze_amount(self):
        return self._freeze_amount

    @freeze_amount.setter
    def freeze_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._freeze_amount = value
        else:
            self._freeze_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.available_amount:
            if hasattr(self.available_amount, 'to_alipay_dict'):
                params['available_amount'] = self.available_amount.to_alipay_dict()
            else:
                params['available_amount'] = self.available_amount
        if self.balance:
            if hasattr(self.balance, 'to_alipay_dict'):
                params['balance'] = self.balance.to_alipay_dict()
            else:
                params['balance'] = self.balance
        if self.freeze_amount:
            if hasattr(self.freeze_amount, 'to_alipay_dict'):
                params['freeze_amount'] = self.freeze_amount.to_alipay_dict()
            else:
                params['freeze_amount'] = self.freeze_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SubAccountBalanceOpenApiDTO()
        if 'available_amount' in d:
            o.available_amount = d['available_amount']
        if 'balance' in d:
            o.balance = d['balance']
        if 'freeze_amount' in d:
            o.freeze_amount = d['freeze_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DataSecCheckResult(object):

    def __init__(self):
        self._check_date = None
        self._data_id = None
        self._data_status = None

    @property
    def check_date(self):
        return self._check_date

    @check_date.setter
    def check_date(self, value):
        self._check_date = value
    @property
    def data_id(self):
        return self._data_id

    @data_id.setter
    def data_id(self, value):
        self._data_id = value
    @property
    def data_status(self):
        return self._data_status

    @data_status.setter
    def data_status(self, value):
        self._data_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.check_date:
            if hasattr(self.check_date, 'to_alipay_dict'):
                params['check_date'] = self.check_date.to_alipay_dict()
            else:
                params['check_date'] = self.check_date
        if self.data_id:
            if hasattr(self.data_id, 'to_alipay_dict'):
                params['data_id'] = self.data_id.to_alipay_dict()
            else:
                params['data_id'] = self.data_id
        if self.data_status:
            if hasattr(self.data_status, 'to_alipay_dict'):
                params['data_status'] = self.data_status.to_alipay_dict()
            else:
                params['data_status'] = self.data_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DataSecCheckResult()
        if 'check_date' in d:
            o.check_date = d['check_date']
        if 'data_id' in d:
            o.data_id = d['data_id']
        if 'data_status' in d:
            o.data_status = d['data_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaMerchantOrderCreditCreateModel(object):

    def __init__(self):
        self._amount = None
        self._category = None
        self._channel = None
        self._deposit = None
        self._from_channel = None
        self._item_id = None
        self._order_process_url = None
        self._out_order_no = None
        self._overdue_time = None
        self._subject = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def category(self):
        return self._category

    @category.setter
    def category(self, value):
        self._category = value
    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def deposit(self):
        return self._deposit

    @deposit.setter
    def deposit(self, value):
        self._deposit = value
    @property
    def from_channel(self):
        return self._from_channel

    @from_channel.setter
    def from_channel(self, value):
        self._from_channel = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def order_process_url(self):
        return self._order_process_url

    @order_process_url.setter
    def order_process_url(self, value):
        self._order_process_url = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def overdue_time(self):
        return self._overdue_time

    @overdue_time.setter
    def overdue_time(self, value):
        self._overdue_time = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.category:
            if hasattr(self.category, 'to_alipay_dict'):
                params['category'] = self.category.to_alipay_dict()
            else:
                params['category'] = self.category
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.deposit:
            if hasattr(self.deposit, 'to_alipay_dict'):
                params['deposit'] = self.deposit.to_alipay_dict()
            else:
                params['deposit'] = self.deposit
        if self.from_channel:
            if hasattr(self.from_channel, 'to_alipay_dict'):
                params['from_channel'] = self.from_channel.to_alipay_dict()
            else:
                params['from_channel'] = self.from_channel
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.order_process_url:
            if hasattr(self.order_process_url, 'to_alipay_dict'):
                params['order_process_url'] = self.order_process_url.to_alipay_dict()
            else:
                params['order_process_url'] = self.order_process_url
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.overdue_time:
            if hasattr(self.overdue_time, 'to_alipay_dict'):
                params['overdue_time'] = self.overdue_time.to_alipay_dict()
            else:
                params['overdue_time'] = self.overdue_time
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaMerchantOrderCreditCreateModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'category' in d:
            o.category = d['category']
        if 'channel' in d:
            o.channel = d['channel']
        if 'deposit' in d:
            o.deposit = d['deposit']
        if 'from_channel' in d:
            o.from_channel = d['from_channel']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'order_process_url' in d:
            o.order_process_url = d['order_process_url']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'overdue_time' in d:
            o.overdue_time = d['overdue_time']
        if 'subject' in d:
            o.subject = d['subject']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.DishonorOrder import DishonorOrder


class AlipayFundTransDishonorQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundTransDishonorQueryResponse, self).__init__()
        self._dishonor_order_list = None
        self._items = None
        self._items_per_page = None
        self._page = None

    @property
    def dishonor_order_list(self):
        return self._dishonor_order_list

    @dishonor_order_list.setter
    def dishonor_order_list(self, value):
        if isinstance(value, list):
            self._dishonor_order_list = list()
            for i in value:
                if isinstance(i, DishonorOrder):
                    self._dishonor_order_list.append(i)
                else:
                    self._dishonor_order_list.append(DishonorOrder.from_alipay_dict(i))
    @property
    def items(self):
        return self._items

    @items.setter
    def items(self, value):
        self._items = value
    @property
    def items_per_page(self):
        return self._items_per_page

    @items_per_page.setter
    def items_per_page(self, value):
        self._items_per_page = value
    @property
    def page(self):
        return self._page

    @page.setter
    def page(self, value):
        self._page = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundTransDishonorQueryResponse, self).parse_response_content(response_content)
        if 'dishonor_order_list' in response:
            self.dishonor_order_list = response['dishonor_order_list']
        if 'items' in response:
            self.items = response['items']
        if 'items_per_page' in response:
            self.items_per_page = response['items_per_page']
        if 'page' in response:
            self.page = response['page']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CommonVoucherDisplayLiteInfo import CommonVoucherDisplayLiteInfo
from alipay.aop.api.domain.CommonVoucherUseRuleLiteInfo import CommonVoucherUseRuleLiteInfo


class UserVoucherInfo(object):

    def __init__(self):
        self._activity_id = None
        self._available_begin_time = None
        self._available_end_time = None
        self._belong_merchant_id = None
        self._create_time = None
        self._voucher_display_lite_info = None
        self._voucher_id = None
        self._voucher_name = None
        self._voucher_status = None
        self._voucher_type = None
        self._voucher_use_rule_lite_info = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def available_begin_time(self):
        return self._available_begin_time

    @available_begin_time.setter
    def available_begin_time(self, value):
        self._available_begin_time = value
    @property
    def available_end_time(self):
        return self._available_end_time

    @available_end_time.setter
    def available_end_time(self, value):
        self._available_end_time = value
    @property
    def belong_merchant_id(self):
        return self._belong_merchant_id

    @belong_merchant_id.setter
    def belong_merchant_id(self, value):
        self._belong_merchant_id = value
    @property
    def create_time(self):
        return self._create_time

    @create_time.setter
    def create_time(self, value):
        self._create_time = value
    @property
    def voucher_display_lite_info(self):
        return self._voucher_display_lite_info

    @voucher_display_lite_info.setter
    def voucher_display_lite_info(self, value):
        if isinstance(value, CommonVoucherDisplayLiteInfo):
            self._voucher_display_lite_info = value
        else:
            self._voucher_display_lite_info = CommonVoucherDisplayLiteInfo.from_alipay_dict(value)
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value
    @property
    def voucher_name(self):
        return self._voucher_name

    @voucher_name.setter
    def voucher_name(self, value):
        self._voucher_name = value
    @property
    def voucher_status(self):
        return self._voucher_status

    @voucher_status.setter
    def voucher_status(self, value):
        self._voucher_status = value
    @property
    def voucher_type(self):
        return self._voucher_type

    @voucher_type.setter
    def voucher_type(self, value):
        self._voucher_type = value
    @property
    def voucher_use_rule_lite_info(self):
        return self._voucher_use_rule_lite_info

    @voucher_use_rule_lite_info.setter
    def voucher_use_rule_lite_info(self, value):
        if isinstance(value, CommonVoucherUseRuleLiteInfo):
            self._voucher_use_rule_lite_info = value
        else:
            self._voucher_use_rule_lite_info = CommonVoucherUseRuleLiteInfo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.available_begin_time:
            if hasattr(self.available_begin_time, 'to_alipay_dict'):
                params['available_begin_time'] = self.available_begin_time.to_alipay_dict()
            else:
                params['available_begin_time'] = self.available_begin_time
        if self.available_end_time:
            if hasattr(self.available_end_time, 'to_alipay_dict'):
                params['available_end_time'] = self.available_end_time.to_alipay_dict()
            else:
                params['available_end_time'] = self.available_end_time
        if self.belong_merchant_id:
            if hasattr(self.belong_merchant_id, 'to_alipay_dict'):
                params['belong_merchant_id'] = self.belong_merchant_id.to_alipay_dict()
            else:
                params['belong_merchant_id'] = self.belong_merchant_id
        if self.create_time:
            if hasattr(self.create_time, 'to_alipay_dict'):
                params['create_time'] = self.create_time.to_alipay_dict()
            else:
                params['create_time'] = self.create_time
        if self.voucher_display_lite_info:
            if hasattr(self.voucher_display_lite_info, 'to_alipay_dict'):
                params['voucher_display_lite_info'] = self.voucher_display_lite_info.to_alipay_dict()
            else:
                params['voucher_display_lite_info'] = self.voucher_display_lite_info
        if self.voucher_id:
            if hasattr(self.voucher_id, 'to_alipay_dict'):
                params['voucher_id'] = self.voucher_id.to_alipay_dict()
            else:
                params['voucher_id'] = self.voucher_id
        if self.voucher_name:
            if hasattr(self.voucher_name, 'to_alipay_dict'):
                params['voucher_name'] = self.voucher_name.to_alipay_dict()
            else:
                params['voucher_name'] = self.voucher_name
        if self.voucher_status:
            if hasattr(self.voucher_status, 'to_alipay_dict'):
                params['voucher_status'] = self.voucher_status.to_alipay_dict()
            else:
                params['voucher_status'] = self.voucher_status
        if self.voucher_type:
            if hasattr(self.voucher_type, 'to_alipay_dict'):
                params['voucher_type'] = self.voucher_type.to_alipay_dict()
            else:
                params['voucher_type'] = self.voucher_type
        if self.voucher_use_rule_lite_info:
            if hasattr(self.voucher_use_rule_lite_info, 'to_alipay_dict'):
                params['voucher_use_rule_lite_info'] = self.voucher_use_rule_lite_info.to_alipay_dict()
            else:
                params['voucher_use_rule_lite_info'] = self.voucher_use_rule_lite_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UserVoucherInfo()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'available_begin_time' in d:
            o.available_begin_time = d['available_begin_time']
        if 'available_end_time' in d:
            o.available_end_time = d['available_end_time']
        if 'belong_merchant_id' in d:
            o.belong_merchant_id = d['belong_merchant_id']
        if 'create_time' in d:
            o.create_time = d['create_time']
        if 'voucher_display_lite_info' in d:
            o.voucher_display_lite_info = d['voucher_display_lite_info']
        if 'voucher_id' in d:
            o.voucher_id = d['voucher_id']
        if 'voucher_name' in d:
            o.voucher_name = d['voucher_name']
        if 'voucher_status' in d:
            o.voucher_status = d['voucher_status']
        if 'voucher_type' in d:
            o.voucher_type = d['voucher_type']
        if 'voucher_use_rule_lite_info' in d:
            o.voucher_use_rule_lite_info = d['voucher_use_rule_lite_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceOrderInfoModifyModel(object):

    def __init__(self):
        self._actual_amount = None
        self._gmt_check_in = None
        self._gmt_check_out = None
        self._inv_status = None
        self._order_id = None
        self._order_status = None
        self._platform_code = None
        self._platform_user_id = None
        self._user_id = None

    @property
    def actual_amount(self):
        return self._actual_amount

    @actual_amount.setter
    def actual_amount(self, value):
        self._actual_amount = value
    @property
    def gmt_check_in(self):
        return self._gmt_check_in

    @gmt_check_in.setter
    def gmt_check_in(self, value):
        self._gmt_check_in = value
    @property
    def gmt_check_out(self):
        return self._gmt_check_out

    @gmt_check_out.setter
    def gmt_check_out(self, value):
        self._gmt_check_out = value
    @property
    def inv_status(self):
        return self._inv_status

    @inv_status.setter
    def inv_status(self, value):
        self._inv_status = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def platform_code(self):
        return self._platform_code

    @platform_code.setter
    def platform_code(self, value):
        self._platform_code = value
    @property
    def platform_user_id(self):
        return self._platform_user_id

    @platform_user_id.setter
    def platform_user_id(self, value):
        self._platform_user_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.actual_amount:
            if hasattr(self.actual_amount, 'to_alipay_dict'):
                params['actual_amount'] = self.actual_amount.to_alipay_dict()
            else:
                params['actual_amount'] = self.actual_amount
        if self.gmt_check_in:
            if hasattr(self.gmt_check_in, 'to_alipay_dict'):
                params['gmt_check_in'] = self.gmt_check_in.to_alipay_dict()
            else:
                params['gmt_check_in'] = self.gmt_check_in
        if self.gmt_check_out:
            if hasattr(self.gmt_check_out, 'to_alipay_dict'):
                params['gmt_check_out'] = self.gmt_check_out.to_alipay_dict()
            else:
                params['gmt_check_out'] = self.gmt_check_out
        if self.inv_status:
            if hasattr(self.inv_status, 'to_alipay_dict'):
                params['inv_status'] = self.inv_status.to_alipay_dict()
            else:
                params['inv_status'] = self.inv_status
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.order_status:
            if hasattr(self.order_status, 'to_alipay_dict'):
                params['order_status'] = self.order_status.to_alipay_dict()
            else:
                params['order_status'] = self.order_status
        if self.platform_code:
            if hasattr(self.platform_code, 'to_alipay_dict'):
                params['platform_code'] = self.platform_code.to_alipay_dict()
            else:
                params['platform_code'] = self.platform_code
        if self.platform_user_id:
            if hasattr(self.platform_user_id, 'to_alipay_dict'):
                params['platform_user_id'] = self.platform_user_id.to_alipay_dict()
            else:
                params['platform_user_id'] = self.platform_user_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceOrderInfoModifyModel()
        if 'actual_amount' in d:
            o.actual_amount = d['actual_amount']
        if 'gmt_check_in' in d:
            o.gmt_check_in = d['gmt_check_in']
        if 'gmt_check_out' in d:
            o.gmt_check_out = d['gmt_check_out']
        if 'inv_status' in d:
            o.inv_status = d['inv_status']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'order_status' in d:
            o.order_status = d['order_status']
        if 'platform_code' in d:
            o.platform_code = d['platform_code']
        if 'platform_user_id' in d:
            o.platform_user_id = d['platform_user_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserWufufukaAliyunRefundModel(object):

    def __init__(self):
        self._alipay_order_id = None
        self._ext_info = None
        self._request_id = None
        self._request_time = None
        self._user_id = None

    @property
    def alipay_order_id(self):
        return self._alipay_order_id

    @alipay_order_id.setter
    def alipay_order_id(self, value):
        self._alipay_order_id = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def request_time(self):
        return self._request_time

    @request_time.setter
    def request_time(self, value):
        self._request_time = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_order_id:
            if hasattr(self.alipay_order_id, 'to_alipay_dict'):
                params['alipay_order_id'] = self.alipay_order_id.to_alipay_dict()
            else:
                params['alipay_order_id'] = self.alipay_order_id
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.request_time:
            if hasattr(self.request_time, 'to_alipay_dict'):
                params['request_time'] = self.request_time.to_alipay_dict()
            else:
                params['request_time'] = self.request_time
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserWufufukaAliyunRefundModel()
        if 'alipay_order_id' in d:
            o.alipay_order_id = d['alipay_order_id']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'request_time' in d:
            o.request_time = d['request_time']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayIserviceCcmSwArticleBatchqueryModel(object):

    def __init__(self):
        self._category_id = None
        self._ccs_instance_id = None
        self._end_time = None
        self._ids = None
        self._keyword = None
        self._keywords = None
        self._library_id = None
        self._page_num = None
        self._page_size = None
        self._search_all_category = None
        self._search_category_type = None
        self._start_time = None
        self._status = None

    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def ccs_instance_id(self):
        return self._ccs_instance_id

    @ccs_instance_id.setter
    def ccs_instance_id(self, value):
        self._ccs_instance_id = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def ids(self):
        return self._ids

    @ids.setter
    def ids(self, value):
        if isinstance(value, list):
            self._ids = list()
            for i in value:
                self._ids.append(i)
    @property
    def keyword(self):
        return self._keyword

    @keyword.setter
    def keyword(self, value):
        self._keyword = value
    @property
    def keywords(self):
        return self._keywords

    @keywords.setter
    def keywords(self, value):
        if isinstance(value, list):
            self._keywords = list()
            for i in value:
                self._keywords.append(i)
    @property
    def library_id(self):
        return self._library_id

    @library_id.setter
    def library_id(self, value):
        self._library_id = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def search_all_category(self):
        return self._search_all_category

    @search_all_category.setter
    def search_all_category(self, value):
        self._search_all_category = value
    @property
    def search_category_type(self):
        return self._search_category_type

    @search_category_type.setter
    def search_category_type(self, value):
        self._search_category_type = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.ccs_instance_id:
            if hasattr(self.ccs_instance_id, 'to_alipay_dict'):
                params['ccs_instance_id'] = self.ccs_instance_id.to_alipay_dict()
            else:
                params['ccs_instance_id'] = self.ccs_instance_id
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.ids:
            if isinstance(self.ids, list):
                for i in range(0, len(self.ids)):
                    element = self.ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ids[i] = element.to_alipay_dict()
            if hasattr(self.ids, 'to_alipay_dict'):
                params['ids'] = self.ids.to_alipay_dict()
            else:
                params['ids'] = self.ids
        if self.keyword:
            if hasattr(self.keyword, 'to_alipay_dict'):
                params['keyword'] = self.keyword.to_alipay_dict()
            else:
                params['keyword'] = self.keyword
        if self.keywords:
            if isinstance(self.keywords, list):
                for i in range(0, len(self.keywords)):
                    element = self.keywords[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.keywords[i] = element.to_alipay_dict()
            if hasattr(self.keywords, 'to_alipay_dict'):
                params['keywords'] = self.keywords.to_alipay_dict()
            else:
                params['keywords'] = self.keywords
        if self.library_id:
            if hasattr(self.library_id, 'to_alipay_dict'):
                params['library_id'] = self.library_id.to_alipay_dict()
            else:
                params['library_id'] = self.library_id
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.search_all_category:
            if hasattr(self.search_all_category, 'to_alipay_dict'):
                params['search_all_category'] = self.search_all_category.to_alipay_dict()
            else:
                params['search_all_category'] = self.search_all_category
        if self.search_category_type:
            if hasattr(self.search_category_type, 'to_alipay_dict'):
                params['search_category_type'] = self.search_category_type.to_alipay_dict()
            else:
                params['search_category_type'] = self.search_category_type
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayIserviceCcmSwArticleBatchqueryModel()
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'ccs_instance_id' in d:
            o.ccs_instance_id = d['ccs_instance_id']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'ids' in d:
            o.ids = d['ids']
        if 'keyword' in d:
            o.keyword = d['keyword']
        if 'keywords' in d:
            o.keywords = d['keywords']
        if 'library_id' in d:
            o.library_id = d['library_id']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'search_all_category' in d:
            o.search_all_category = d['search_all_category']
        if 'search_category_type' in d:
            o.search_category_type = d['search_category_type']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'status' in d:
            o.status = d['status']
        return o


